pub enum AmountType {
ExactInput,
ExactOutput,
}Expand description
Whether the amount refers to the input token or output token.
JSON schema
{
"title": "AmountType",
"description": "Whether the amount refers to the input token or output
token.",
"type": "string",
"enum": [
"exact_input",
"exact_output"
],
"x-stainless-model": "wallets.amount_type"
}Variants