pub enum ExtendedChainType {
Aptos,
BitcoinSegwit,
Cosmos,
Movement,
Near,
Spark,
Starknet,
Stellar,
Sui,
Ton,
Tron,
}Expand description
The wallet chain types that are not first class chains.
JSON schema
{
"title": "ExtendedChainType",
"description": "The wallet chain types that are not first class
chains.",
"type": "string",
"enum": [
"aptos",
"bitcoin-segwit",
"cosmos",
"movement",
"near",
"spark",
"starknet",
"stellar",
"sui",
"ton",
"tron"
],
"x-stainless-model": "wallets.extended_chain_type"
}Variants