pub enum GetAccountBalanceTestnetMode {
False,
True,
}Expand description
When set to true, returns balances from testnet chains instead of mainnets.
JSON schema
{
"description": "When set to true, returns balances from testnet chains
instead of mainnets.",
"type": "string",
"enum": [
"false",
"true"
]
}Variants