pub enum GetWalletBalanceIncludeCurrency {
Eur,
Usd,
}Expand description
If set, balances are converted to the specified fiat currency. Not
supported when token is provided.
JSON schema
{
"description": "If set, balances are converted to the specified fiat
currency. Not supported when `token` is provided.",
"type": "string",
"enum": [
"eur",
"usd"
]
}Variants