KrakenEmbedStartIdentityMetadataNationality

Enum KrakenEmbedStartIdentityMetadataNationality 

pub enum KrakenEmbedStartIdentityMetadataNationality {
Show 262 variants X0c, Ac, Ad, Ae, Af, Ag, Ai, Al, Am, An, Ao, Ap, Aq, Ar, As, At, Au, Aw, Ax, Az, Ba, Bb, Bd, Be, Bf, Bg, Bh, Bi, Bj, Bl, Bm, Bn, Bo, Bq, Br, Bs, Bt, Bv, Bw, By, Bz, Ca, Cc, Cd, Cf, Cg, Ch, Ci, Ck, Cl, Cm, Cn, Co, Cp, Cr, Cu, Cv, Cw, Cx, Cy, Cz, De, Dg, Dj, Dk, Dm, Do, Dz, Ea, Ec, Ee, Eg, Eh, Er, Es, Et, Eu, Fi, Fj, Fk, Fm, Fo, Fr, Ga, Gb, Gd, Ge, Gf, Gg, Gh, Gi, Gl, Gm, Gn, Gp, Gq, Gr, Gs, Gt, Gu, Gw, Gy, Hk, Hm, Hn, Hr, Ht, Hu, Ic, Id, Ie, Il, Im, In, Io, Iq, Ir, Is, It, Je, Jm, Jo, Jp, Jx, Ke, Kg, Kh, Ki, Km, Kn, Kp, Kr, Kw, Ky, Kz, La, Lb, Lc, Li, Lk, Lr, Ls, Lt, Lu, Lv, Ly, Ma, Mc, Md, Me, Mf, Mg, Mh, Mk, Ml, Mm, Mn, Mo, Mp, Mq, Mr, Ms, Mt, Mu, Mv, Mw, Mx, My, Mz, Na, Nc, Ne, Nf, Ng, Ni, Nl, No, Np, Nr, Nu, Nz, Om, Pa, Pe, Pf, Pg, Ph, Pk, Pl, Pm, Pn, Pr, Ps, Pt, Pw, Py, Qa, Qo, Re, Ro, Rs, Ru, Rw, Sa, Sb, Sc, Sd, Se, Sg, Sh, Si, Sj, Sk, Sl, Sm, Sn, So, Sr, Ss, St, Sv, Sx, Sy, Sz, Ta, Tc, Td, Tf, Tg, Th, Tj, Tk, Tl, Tm, Tn, To, Tr, Tt, Tv, Tw, Tz, Ua, Ug, Um, Us, Uy, Uz, Va, Vc, Ve, Vg, Vi, Vn, Vu, Wf, Ws, Xk, Ye, Yt, Za, Zm, Zw,
}
KrakenEmbedStartIdentityMetadataNationality

JSON schema
{
 "type": "string",
 "enum": [
   "0C",
   "AC",
   "AD",
   "AE",
   "AF",
   "AG",
   "AI",
   "AL",
   "AM",
   "AN",
   "AO",
   "AP",
   "AQ",
   "AR",
   "AS",
   "AT",
   "AU",
   "AW",
   "AX",
   "AZ",
   "BA",
   "BB",
   "BD",
   "BE",
   "BF",
   "BG",
   "BH",
   "BI",
   "BJ",
   "BL",
   "BM",
   "BN",
   "BO",
   "BQ",
   "BR",
   "BS",
   "BT",
   "BV",
   "BW",
   "BY",
   "BZ",
   "CA",
   "CC",
   "CD",
   "CF",
   "CG",
   "CH",
   "CI",
   "CK",
   "CL",
   "CM",
   "CN",
   "CO",
   "CP",
   "CR",
   "CU",
   "CV",
   "CW",
   "CX",
   "CY",
   "CZ",
   "DE",
   "DG",
   "DJ",
   "DK",
   "DM",
   "DO",
   "DZ",
   "EA",
   "EC",
   "EE",
   "EG",
   "EH",
   "ER",
   "ES",
   "ET",
   "EU",
   "FI",
   "FJ",
   "FK",
   "FM",
   "FO",
   "FR",
   "GA",
   "GB",
   "GD",
   "GE",
   "GF",
   "GG",
   "GH",
   "GI",
   "GL",
   "GM",
   "GN",
   "GP",
   "GQ",
   "GR",
   "GS",
   "GT",
   "GU",
   "GW",
   "GY",
   "HK",
   "HM",
   "HN",
   "HR",
   "HT",
   "HU",
   "IC",
   "ID",
   "IE",
   "IL",
   "IM",
   "IN",
   "IO",
   "IQ",
   "IR",
   "IS",
   "IT",
   "JE",
   "JM",
   "JO",
   "JP",
   "JX",
   "KE",
   "KG",
   "KH",
   "KI",
   "KM",
   "KN",
   "KP",
   "KR",
   "KW",
   "KY",
   "KZ",
   "LA",
   "LB",
   "LC",
   "LI",
   "LK",
   "LR",
   "LS",
   "LT",
   "LU",
   "LV",
   "LY",
   "MA",
   "MC",
   "MD",
   "ME",
   "MF",
   "MG",
   "MH",
   "MK",
   "ML",
   "MM",
   "MN",
   "MO",
   "MP",
   "MQ",
   "MR",
   "MS",
   "MT",
   "MU",
   "MV",
   "MW",
   "MX",
   "MY",
   "MZ",
   "NA",
   "NC",
   "NE",
   "NF",
   "NG",
   "NI",
   "NL",
   "NO",
   "NP",
   "NR",
   "NU",
   "NZ",
   "OM",
   "PA",
   "PE",
   "PF",
   "PG",
   "PH",
   "PK",
   "PL",
   "PM",
   "PN",
   "PR",
   "PS",
   "PT",
   "PW",
   "PY",
   "QA",
   "QO",
   "RE",
   "RO",
   "RS",
   "RU",
   "RW",
   "SA",
   "SB",
   "SC",
   "SD",
   "SE",
   "SG",
   "SH",
   "SI",
   "SJ",
   "SK",
   "SL",
   "SM",
   "SN",
   "SO",
   "SR",
   "SS",
   "ST",
   "SV",
   "SX",
   "SY",
   "SZ",
   "TA",
   "TC",
   "TD",
   "TF",
   "TG",
   "TH",
   "TJ",
   "TK",
   "TL",
   "TM",
   "TN",
   "TO",
   "TR",
   "TT",
   "TV",
   "TW",
   "TZ",
   "UA",
   "UG",
   "UM",
   "US",
   "UY",
   "UZ",
   "VA",
   "VC",
   "VE",
   "VG",
   "VI",
   "VN",
   "VU",
   "WF",
   "WS",
   "XK",
   "YE",
   "YT",
   "ZA",
   "ZM",
   "ZW"
 ]
}

Variants



X0c



Ac



Ad



Ae



Af



Ag



Ai



Al



Am



An



Ao



Ap



Aq



Ar



As



At



Au



Aw



Ax



Az



Ba



Bb



Bd



Be



Bf



Bg



Bh



Bi



Bj



Bl



Bm



Bn



Bo



Bq



Br



Bs



Bt



Bv



Bw



By



Bz



Ca



Cc



Cd



Cf



Cg



Ch



Ci



Ck



Cl



Cm



Cn



Co



Cp



Cr



Cu



Cv



Cw



Cx



Cy



Cz



De



Dg



Dj



Dk



Dm



Do



Dz



Ea



Ec



Ee



Eg



Eh



Er



Es



Et



Eu



Fi



Fj



Fk



Fm



Fo



Fr



Ga



Gb



Gd



Ge



Gf



Gg



Gh



Gi



Gl



Gm



Gn



Gp



Gq



Gr



Gs



Gt



Gu



Gw



Gy



Hk



Hm



Hn



Hr



Ht



Hu



Ic



Id



Ie



Il



Im



In



Io



Iq



Ir



Is



It



Je



Jm



Jo



Jp



Jx



Ke



Kg



Kh



Ki



Km



Kn



Kp



Kr



Kw



Ky



Kz



La



Lb



Lc



Li



Lk



Lr



Ls



Lt



Lu



Lv



Ly



Ma



Mc



Md



Me



Mf



Mg



Mh



Mk



Ml



Mm



Mn



Mo



Mp



Mq



Mr



Ms



Mt



Mu



Mv



Mw



Mx



My



Mz



Na



Nc



Ne



Nf



Ng



Ni



Nl



No



Np



Nr



Nu



Nz



Om



Pa



Pe



Pf



Pg



Ph



Pk



Pl



Pm



Pn



Pr



Ps



Pt



Pw



Py



Qa



Qo



Re



Ro



Rs



Ru



Rw



Sa



Sb



Sc



Sd



Se



Sg



Sh



Si



Sj



Sk



Sl



Sm



Sn



So



Sr



Ss



St



Sv



Sx



Sy



Sz



Ta



Tc



Td



Tf



Tg



Th



Tj



Tk



Tl



Tm



Tn



To



Tr



Tt



Tv



Tw



Tz



Ua



Ug



Um



Us



Uy



Uz



Va



Vc



Ve



Vg



Vi



Vn



Vu



Wf



Ws



Xk



Ye



Yt



Za



Zm



Zw