pub enum OwnerInput {
Variant0(OwnerInputUser),
Variant1(OwnerInputPublicKey),
Variant2(String),
Variant3(String),
}Expand description
The owner of the resource, specified as a Privy user ID, a P-256 public key, or null to remove the current owner.
JSON schema
{
"title": "OwnerInput",
"description": "The owner of the resource, specified as a Privy user
ID, a P-256 public key, or null to remove the current owner.",
"oneOf": [
{
"$ref": "#/components/schemas/OwnerInputUser"
},
{
"$ref": "#/components/schemas/OwnerInputPublicKey"
},
{
"type": "string"
},
{
"type": "string"
}
],
"x-stainless-model": "shared.owner_input"
}Variants