pub enum PolicyAction {
Allow,
Deny,
}Expand description
The action to take when a policy rule matches.
JSON schema
{
"title": "PolicyAction",
"description": "The action to take when a policy rule matches.",
"type": "string",
"enum": [
"ALLOW",
"DENY"
],
"x-stainless-model": "policies.policy_action"
}Variants