pub enum Quantity {
Hex(Hex),
Integer(i64),
}Expand description
A quantity value that can be either a hex string starting with ‘0x’ or a non-negative integer.
JSON schema
{
"title": "Quantity",
"description": "A quantity value that can be either a hex string
starting with '0x' or a non-negative integer.",
"oneOf": [
{
"$ref": "#/components/schemas/Hex"
},
{
"type": "integer",
"maximum": 9007199254740991.0,
"minimum": -9007199254740991.0
}
],
"x-stainless-model": "wallets.quantity"
}Variants