pub enum WalletAuthenticateIntentsResponse {
EncryptedBoundAuthenticateResponse(EncryptedBoundAuthenticateResponse),
RawBoundAuthenticateResponse(RawBoundAuthenticateResponse),
}Expand description
The response from authenticating a wallet with intent bindings, containing an authorization key, wallet data, and the bindings the key is scoped to.
JSON schema
{
"title": "WalletAuthenticateIntentsResponse",
"description": "The response from authenticating a wallet with intent
bindings, containing an authorization key, wallet data, and the bindings
the key is scoped to.",
"oneOf": [
{
"$ref": "#/components/schemas/EncryptedBoundAuthenticateResponse"
},
{
"$ref": "#/components/schemas/RawBoundAuthenticateResponse"
}
],
"x-stainless-model": "wallets.wallet_authenticate_intents_response"
}Variants
EncryptedBoundAuthenticateResponse(EncryptedBoundAuthenticateResponse)
RawBoundAuthenticateResponse(RawBoundAuthenticateResponse)