pub enum WalletBatchCreateResult {
Success {
index: f64,
success: bool,
wallet: Wallet,
},
Failure {
code: String,
error: String,
index: f64,
success: bool,
},
}Expand description
A single result from a batch wallet creation operation.
JSON schema
{
"title": "WalletBatchCreateResult",
"description": "A single result from a batch wallet creation
operation.",
"oneOf": [
{
"title": "WalletBatchCreateSuccess",
"description": "A successful wallet creation result within a batch
operation.",
"type": "object",
"required": [
"index",
"success",
"wallet"
],
"properties": {
"index": {
"description": "The index of the wallet in the original request
array.",
"type": "number"
},
"success": {
"type": "boolean",
"enum": [
true
]
},
"wallet": {
"$ref": "#/components/schemas/Wallet"
}
}
},
{
"title": "WalletBatchCreateFailure",
"description": "A failed wallet creation result within a batch
operation.",
"type": "object",
"required": [
"code",
"error",
"index",
"success"
],
"properties": {
"code": {
"description": "A PrivyErrorCode string identifying the error
type (e.g., \"invalid_data\", \"resource_conflict\").",
"type": "string"
},
"error": {
"description": "A human-readable error message with details
about what went wrong.",
"type": "string"
},
"index": {
"description": "The index of the wallet in the original request
array.",
"type": "number"
},
"success": {
"type": "boolean",
"enum": [
false
]
}
}
}
],
"x-stainless-model": "wallets.wallet_batch_create_result"
}Variants