pub struct AccountBalanceResponse {
pub assets: Vec<BalanceAsset>,
pub assets_by_chain: Vec<BalanceAssetByChain>,
pub total: CurrencyAmount,
}Expand description
The balance of a digital asset account, aggregated across all wallets and supported chains.
JSON schema
{
"title": "AccountBalanceResponse",
"description": "The balance of a digital asset account, aggregated
across all wallets and supported chains.",
"type": "object",
"required": [
"assets",
"total"
],
"properties": {
"assets": {
"description": "The individual asset balances, each computed across
all supported chains.",
"type": "array",
"items": {
"$ref": "#/components/schemas/BalanceAsset"
}
},
"assets_by_chain": {
"description": "Individual asset balances per chain.",
"type": "array",
"items": {
"$ref": "#/components/schemas/BalanceAssetByChain"
}
},
"total": {
"allOf": [
{
"$ref": "#/components/schemas/CurrencyAmount"
},
{
"description": "The total balance across all assets."
}
]
}
},
"x-stainless-model": "accounts.account_balance_response"
}Fields
assets: Vec<BalanceAsset>The individual asset balances, each computed across all supported chains.
assets_by_chain: Vec<BalanceAssetByChain>Individual asset balances per chain.
total: CurrencyAmountTrait Implementations
Sourceimpl Clone for AccountBalanceResponse
impl Clone for AccountBalanceResponse
Sourcefn clone(&self) -> AccountBalanceResponse
fn clone(&self) -> AccountBalanceResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AccountBalanceResponse
impl Debug for AccountBalanceResponse
Sourceimpl<'de> Deserialize<'de> for AccountBalanceResponse
impl<'de> Deserialize<'de> for AccountBalanceResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&AccountBalanceResponse> for AccountBalanceResponse
impl From<&AccountBalanceResponse> for AccountBalanceResponse
Sourcefn from(value: &AccountBalanceResponse) -> Self
fn from(value: &AccountBalanceResponse) -> Self
Converts to this type from the input type.