pub struct AccountsDashboardListResponse {
pub data: Vec<AssetAccountWithBalance>,
pub next_cursor: Option<String>,
}Expand description
Paginated list of digital asset accounts for the dashboard.
JSON schema
{
"title": "AccountsDashboardListResponse",
"description": "Paginated list of digital asset accounts for the
dashboard.",
"type": "object",
"required": [
"data"
],
"properties": {
"data": {
"description": "The list of accounts, with balances included for
dashboard display.",
"type": "array",
"items": {
"$ref": "#/components/schemas/AssetAccountWithBalance"
}
},
"next_cursor": {
"description": "Cursor for fetching the next page of results, or
null if no more results.",
"type": "string"
}
},
"x-stainless-model": "accounts.accounts_dashboard_list_response"
}Fields
data: Vec<AssetAccountWithBalance>The list of accounts, with balances included for dashboard display.
next_cursor: Option<String>Cursor for fetching the next page of results, or null if no more results.