pub struct AccountsListResponse {
pub data: Vec<AccountResponse>,
pub next_cursor: Option<String>,
}Expand description
Paginated list of digital asset accounts.
JSON schema
{
"title": "AccountsListResponse",
"description": "Paginated list of digital asset accounts.",
"type": "object",
"required": [
"data"
],
"properties": {
"data": {
"description": "The list of accounts.",
"type": "array",
"items": {
"$ref": "#/components/schemas/AccountResponse"
}
},
"next_cursor": {
"description": "Cursor for fetching the next page of results, or
null if no more results.",
"type": "string"
}
},
"x-stainless-model": "accounts.accounts_list_response"
}Fields
data: Vec<AccountResponse>The list of accounts.
next_cursor: Option<String>Cursor for fetching the next page of results, or null if no more results.