pub struct Aggregation {
pub conditions: Vec<PolicyCondition>,
pub created_at: f64,
pub group_by: Vec<AggregationGroupBy>,
pub id: String,
pub method: AggregationMethod,
pub metric: AggregationMetric,
pub name: AggregationName,
pub owner_id: Option<String>,
pub window: AggregationWindow,
}Expand description
An aggregation that measures and tracks metrics over a period of time.
JSON schema
{
"title": "Aggregation",
"description": "An aggregation that measures and tracks metrics over a
period of time.",
"type": "object",
"required": [
"created_at",
"id",
"method",
"metric",
"name",
"window"
],
"properties": {
"conditions": {
"description": "Optional conditions to filter events before
aggregation.",
"default": [],
"type": "array",
"items": {
"$ref": "#/components/schemas/PolicyCondition"
},
"maxItems": 100
},
"created_at": {
"description": "Unix timestamp of when the aggregation was created
in milliseconds.",
"type": "number"
},
"group_by": {
"description": "Optional grouping configuration for bucketing
metrics.",
"default": [],
"type": "array",
"items": {
"$ref": "#/components/schemas/AggregationGroupBy"
},
"maxItems": 2
},
"id": {
"description": "Unique ID of the aggregation.",
"type": "string"
},
"method": {
"$ref": "#/components/schemas/AggregationMethod"
},
"metric": {
"$ref": "#/components/schemas/AggregationMetric"
},
"name": {
"description": "The name of the aggregation.",
"type": "string",
"maxLength": 255,
"minLength": 1
},
"owner_id": {
"description": "The key quorum ID of the owner of the
aggregation.",
"type": "string"
},
"window": {
"$ref": "#/components/schemas/AggregationWindow"
}
},
"x-stainless-model": "aggregations.aggregation"
}Fields
conditions: Vec<PolicyCondition>Optional conditions to filter events before aggregation.
created_at: f64group_by: Vec<AggregationGroupBy>Optional grouping configuration for bucketing metrics.
id: StringUnique ID of the aggregation.
method: AggregationMethodmetric: AggregationMetricname: AggregationNameThe name of the aggregation.
owner_id: Option<String>The key quorum ID of the owner of the aggregation.
window: AggregationWindowTrait Implementations
Sourceimpl Clone for Aggregation
impl Clone for Aggregation
Sourcefn clone(&self) -> Aggregation
fn clone(&self) -> Aggregation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Aggregation
impl Debug for Aggregation
Sourceimpl<'de> Deserialize<'de> for Aggregation
impl<'de> Deserialize<'de> for Aggregation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&Aggregation> for Aggregation
impl From<&Aggregation> for Aggregation
Sourcefn from(value: &Aggregation) -> Self
fn from(value: &Aggregation) -> Self
Converts to this type from the input type.