pub struct AggregationMetric {
pub abi: Option<AbiSchema>,
pub field: String,
pub field_source: String,
pub function: AggregationMetricFunction,
}Expand description
The metric configuration for an aggregation, defining what field/field_source to measure and the aggregation function to apply.
JSON schema
{
"title": "AggregationMetric",
"description": "The metric configuration for an aggregation, defining
what field/field_source to measure and the aggregation function to
apply.",
"type": "object",
"required": [
"field",
"field_source",
"function"
],
"properties": {
"abi": {
"$ref": "#/components/schemas/AbiSchema"
},
"field": {
"type": "string"
},
"field_source": {
"type": "string"
},
"function": {
"description": "The aggregation function to apply.",
"type": "string",
"enum": [
"sum"
]
}
},
"x-stainless-model": "aggregations.aggregation_metric"
}Fields
abi: Option<AbiSchema>field: Stringfield_source: Stringfunction: AggregationMetricFunctionThe aggregation function to apply.