pub struct BalanceAsset {
pub amount: String,
pub price: CurrencyAmount,
pub symbol: String,
}Expand description
A single asset entry in a balance, representing holdings across all supported chains.
JSON schema
{
"title": "BalanceAsset",
"description": "A single asset entry in a balance, representing
holdings across all supported chains.",
"type": "object",
"required": [
"amount",
"price",
"symbol"
],
"properties": {
"amount": {
"description": "The amount of the asset held, denominated in the
unit of the asset itself, with 1 decimal of precision.",
"type": "string"
},
"price": {
"allOf": [
{
"$ref": "#/components/schemas/CurrencyAmount"
},
{
"description": "The price of the asset in the provided
currency."
}
]
},
"symbol": {
"description": "The symbol of the asset (e.g. USDC, ETH).",
"type": "string"
}
},
"x-stainless-model": "accounts.balance_asset"
}Fields
amount: StringThe amount of the asset held, denominated in the unit of the asset itself, with 1 decimal of precision.
price: CurrencyAmountsymbol: StringThe symbol of the asset (e.g. USDC, ETH).