pub struct BridgeCryptoDepositMetadata {
pub drain_id: String,
pub liquidation_address: String,
pub liquidation_address_id: String,
pub method: BridgeCryptoDepositMetadataMethod,
pub source_wallet_address: String,
pub type_: BridgeCryptoDepositMetadataType,
}Expand description
Bridge metadata for a crypto deposit via liquidation address.
JSON schema
{
"title": "BridgeCryptoDepositMetadata",
"description": "Bridge metadata for a crypto deposit via liquidation
address.",
"type": "object",
"required": [
"drain_id",
"liquidation_address",
"liquidation_address_id",
"method",
"source_wallet_address",
"type"
],
"properties": {
"drain_id": {
"type": "string"
},
"liquidation_address": {
"description": "The crypto address of the liquidation address that
received the deposit.",
"type": "string"
},
"liquidation_address_id": {
"type": "string"
},
"method": {
"type": "string",
"enum": [
"liquidation_address"
]
},
"source_wallet_address": {
"description": "The address that sent the deposit.",
"type": "string"
},
"type": {
"type": "string",
"enum": [
"crypto_deposit"
]
}
},
"x-stainless-model": "webhooks.bridge_crypto_deposit_metadata"
}Fields
drain_id: Stringliquidation_address: StringThe crypto address of the liquidation address that received the deposit.
liquidation_address_id: Stringmethod: BridgeCryptoDepositMetadataMethodsource_wallet_address: StringThe address that sent the deposit.
type_: BridgeCryptoDepositMetadataTypeTrait Implementations
Sourceimpl Clone for BridgeCryptoDepositMetadata
impl Clone for BridgeCryptoDepositMetadata
Sourcefn clone(&self) -> BridgeCryptoDepositMetadata
fn clone(&self) -> BridgeCryptoDepositMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BridgeCryptoDepositMetadata
impl Debug for BridgeCryptoDepositMetadata
Sourceimpl<'de> Deserialize<'de> for BridgeCryptoDepositMetadata
impl<'de> Deserialize<'de> for BridgeCryptoDepositMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&BridgeCryptoDepositMetadata> for BridgeCryptoDepositMetadata
impl From<&BridgeCryptoDepositMetadata> for BridgeCryptoDepositMetadata
Sourcefn from(value: &BridgeCryptoDepositMetadata) -> Self
fn from(value: &BridgeCryptoDepositMetadata) -> Self
Converts to this type from the input type.
Sourceimpl From<BridgeCryptoDepositMetadata> for BridgeMetadata
impl From<BridgeCryptoDepositMetadata> for BridgeMetadata
Sourcefn from(value: BridgeCryptoDepositMetadata) -> Self
fn from(value: BridgeCryptoDepositMetadata) -> Self
Converts to this type from the input type.