ConditionSetAuthorizationHeaders

Struct ConditionSetAuthorizationHeaders 

pub struct ConditionSetAuthorizationHeaders {
    pub privy_app_id: String,
    pub privy_authorization_signature: Option<String>,
    pub privy_request_expiry: Option<String>,
}
Headers required to authorize modifications to condition sets.

JSON schema
{
 "title": "ConditionSetAuthorizationHeaders",
 "description": "Headers required to authorize modifications to
condition sets.",
 "type": "object",
 "required": [
   "privy-app-id"
 ],
 "properties": {
   "privy-app-id": {
     "description": "ID of your Privy app.",
     "type": "string"
   },
   "privy-authorization-signature": {
     "description": "Request authorization signature. If multiple
signatures are required, they should be comma separated.",
     "type": "string"
   },
   "privy-request-expiry": {
     "description": "Request expiry. Value is a Unix timestamp in
milliseconds representing the deadline by which the request must be
processed.",
     "type": "string"
   }
 },
 "x-stainless-model": "policies.condition_set_authorization_headers"
}

Fields

privy_app_id: String

ID of your Privy app.

privy_authorization_signature: Option<String>

Request authorization signature. If multiple signatures are required, they should be comma separated.

privy_request_expiry: Option<String>

Request expiry. Value is a Unix timestamp in milliseconds representing the deadline by which the request must be processed.