pub struct ConditionSetItemRequestParams {
pub condition_set_id: ConditionSetItemRequestParamsConditionSetId,
pub condition_set_item_id: ConditionSetItemRequestParamsConditionSetItemId,
}Expand description
Unique IDs of the condition set and the condition set item within the condition set to take actions on.
JSON schema
{
"description": "Unique IDs of the condition set and the condition set
item within the condition set to take actions on.",
"type": "object",
"required": [
"condition_set_id",
"condition_set_item_id"
],
"properties": {
"condition_set_id": {
"type": "string",
"maxLength": 24,
"minLength": 24
},
"condition_set_item_id": {
"type": "string",
"maxLength": 24,
"minLength": 24
}
}
}Fields
condition_set_id: ConditionSetItemRequestParamsConditionSetIdcondition_set_item_id: ConditionSetItemRequestParamsConditionSetItemIdTrait Implementations
Sourceimpl Clone for ConditionSetItemRequestParams
impl Clone for ConditionSetItemRequestParams
Sourcefn clone(&self) -> ConditionSetItemRequestParams
fn clone(&self) -> ConditionSetItemRequestParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ConditionSetItemRequestParams
impl<'de> Deserialize<'de> for ConditionSetItemRequestParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&ConditionSetItemRequestParams> for ConditionSetItemRequestParams
impl From<&ConditionSetItemRequestParams> for ConditionSetItemRequestParams
Sourcefn from(value: &ConditionSetItemRequestParams) -> Self
fn from(value: &ConditionSetItemRequestParams) -> Self
Converts to this type from the input type.