pub struct ConditionSetItemValueInput {
pub value: ConditionSetItemValueInputValue,
}Expand description
A single value to add to a condition set.
JSON schema
{
"title": "ConditionSetItemValueInput",
"description": "A single value to add to a condition set.",
"type": "object",
"required": [
"value"
],
"properties": {
"value": {
"type": "string",
"minLength": 1
}
},
"x-stainless-model": "policies.condition_set_item_value_input"
}Fields
value: ConditionSetItemValueInputValueTrait Implementations
Sourceimpl Clone for ConditionSetItemValueInput
impl Clone for ConditionSetItemValueInput
Sourcefn clone(&self) -> ConditionSetItemValueInput
fn clone(&self) -> ConditionSetItemValueInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConditionSetItemValueInput
impl Debug for ConditionSetItemValueInput
Sourceimpl<'de> Deserialize<'de> for ConditionSetItemValueInput
impl<'de> Deserialize<'de> for ConditionSetItemValueInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&ConditionSetItemValueInput> for ConditionSetItemValueInput
impl From<&ConditionSetItemValueInput> for ConditionSetItemValueInput
Sourcefn from(value: &ConditionSetItemValueInput) -> Self
fn from(value: &ConditionSetItemValueInput) -> Self
Converts to this type from the input type.