pub struct CreateAccountFromWalletsConfigurationInput {
pub display_name: Option<AccountDisplayName>,
pub wallets_configuration: AccountWalletsConfiguration,
}Expand description
Input for creating a digital asset account from new wallets with a
wallets_configuration specification.
JSON schema
{
"title": "CreateAccountFromWalletsConfigurationInput",
"description": "Input for creating a digital asset account from new
wallets with a `wallets_configuration` specification.",
"type": "object",
"required": [
"wallets_configuration"
],
"properties": {
"display_name": {
"$ref": "#/components/schemas/AccountDisplayName"
},
"wallets_configuration": {
"allOf": [
{
"$ref": "#/components/schemas/AccountWalletsConfiguration"
},
{
"minItems": 1
}
]
}
},
"x-stainless-model":
"accounts.create_account_from_wallets_configuration_input"
}Fields
display_name: Option<AccountDisplayName>wallets_configuration: AccountWalletsConfigurationTrait Implementations
Sourceimpl Clone for CreateAccountFromWalletsConfigurationInput
impl Clone for CreateAccountFromWalletsConfigurationInput
Sourcefn clone(&self) -> CreateAccountFromWalletsConfigurationInput
fn clone(&self) -> CreateAccountFromWalletsConfigurationInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CreateAccountFromWalletsConfigurationInput
impl<'de> Deserialize<'de> for CreateAccountFromWalletsConfigurationInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&CreateAccountFromWalletsConfigurationInput> for CreateAccountFromWalletsConfigurationInput
impl From<&CreateAccountFromWalletsConfigurationInput> for CreateAccountFromWalletsConfigurationInput
Sourcefn from(value: &CreateAccountFromWalletsConfigurationInput) -> Self
fn from(value: &CreateAccountFromWalletsConfigurationInput) -> Self
Converts to this type from the input type.
Sourceimpl From<CreateAccountFromWalletsConfigurationInput> for CreateAccountInput
impl From<CreateAccountFromWalletsConfigurationInput> for CreateAccountInput
Sourcefn from(value: CreateAccountFromWalletsConfigurationInput) -> Self
fn from(value: CreateAccountFromWalletsConfigurationInput) -> Self
Converts to this type from the input type.