pub struct CreateLinkAuthIntentInput {
pub email: Option<String>,
}Expand description
Input for creating a Link auth intent to initiate Stripe onramp authentication.
JSON schema
{
"title": "CreateLinkAuthIntentInput",
"description": "Input for creating a Link auth intent to initiate
Stripe onramp authentication.",
"type": "object",
"properties": {
"email": {
"type": "string",
"format": "email"
}
},
"x-stainless-model": "onramps.create_link_auth_intent_input"
}Fields
email: Option<String>Trait Implementations
Sourceimpl Clone for CreateLinkAuthIntentInput
impl Clone for CreateLinkAuthIntentInput
Sourcefn clone(&self) -> CreateLinkAuthIntentInput
fn clone(&self) -> CreateLinkAuthIntentInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateLinkAuthIntentInput
impl Debug for CreateLinkAuthIntentInput
Sourceimpl Default for CreateLinkAuthIntentInput
impl Default for CreateLinkAuthIntentInput
Sourceimpl<'de> Deserialize<'de> for CreateLinkAuthIntentInput
impl<'de> Deserialize<'de> for CreateLinkAuthIntentInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&CreateLinkAuthIntentInput> for CreateLinkAuthIntentInput
impl From<&CreateLinkAuthIntentInput> for CreateLinkAuthIntentInput
Sourcefn from(value: &CreateLinkAuthIntentInput) -> Self
fn from(value: &CreateLinkAuthIntentInput) -> Self
Converts to this type from the input type.