pub struct CustomJwtAuthenticateRequestBody {
pub mode: Option<CustomJwtAuthenticateRequestBodyMode>,
pub token: Option<String>,
}Expand description
The request body for authenticating with a custom JWT
JSON schema
{
"title": "CustomJwtAuthenticateRequestBody",
"description": "The request body for authenticating with a custom JWT",
"type": "object",
"properties": {
"mode": {
"type": "string",
"enum": [
"login-or-sign-up",
"no-signup"
]
},
"token": {
"type": "string"
}
}
}Fields
mode: Option<CustomJwtAuthenticateRequestBodyMode>token: Option<String>Trait Implementations
Sourceimpl Clone for CustomJwtAuthenticateRequestBody
impl Clone for CustomJwtAuthenticateRequestBody
Sourcefn clone(&self) -> CustomJwtAuthenticateRequestBody
fn clone(&self) -> CustomJwtAuthenticateRequestBody
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CustomJwtAuthenticateRequestBody
impl<'de> Deserialize<'de> for CustomJwtAuthenticateRequestBody
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&CustomJwtAuthenticateRequestBody> for CustomJwtAuthenticateRequestBody
impl From<&CustomJwtAuthenticateRequestBody> for CustomJwtAuthenticateRequestBody
Sourcefn from(value: &CustomJwtAuthenticateRequestBody) -> Self
fn from(value: &CustomJwtAuthenticateRequestBody) -> Self
Converts to this type from the input type.