pub struct CustomTokenTransferSource {
pub amount: CustomTokenTransferSourceAmount,
pub asset_address: CustomTokenTransferSourceAssetAddress,
pub chain: String,
}Expand description
Source for a transfer identified by a token contract address (EVM) or mint address (Solana). Use this variant for tokens that are not first-class assets.
JSON schema
{
"title": "CustomTokenTransferSource",
"description": "Source for a transfer identified by a token contract
address (EVM) or mint address (Solana). Use this variant for tokens that
are not first-class assets.",
"examples": [
{
"amount": "10.5",
"asset_address": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
"chain": "base"
}
],
"type": "object",
"required": [
"amount",
"asset_address",
"chain"
],
"properties": {
"amount": {
"description": "Amount as a decimal string in the token's standard unit (e.g. \"1.5\" for 1.5 USDC, \"0.01\" for 0.01 ETH). Not in the smallest on-chain unit (wei, lamports, etc.). Maximum 100 characters.",
"type": "string",
"maxLength": 100
},
"asset_address": {
"description": "The token contract address (EVM) or mint address
(Solana) of the asset to transfer.",
"oneOf": [
{
"type": "string"
},
{
"type": "string"
},
{
"$ref": "#/components/schemas/TronAddress"
}
]
},
"chain": {
"description": "The blockchain network on which to perform the
transfer. Supported chains include: 'ethereum', 'base', 'arbitrum',
'polygon', 'solana', and their respective testnets.",
"type": "string"
}
},
"x-stainless-model": "wallets.custom_token_transfer_source"
}Fields
amount: CustomTokenTransferSourceAmountAmount as a decimal string in the token’s standard unit (e.g. “1.5” for 1.5 USDC, “0.01” for 0.01 ETH). Not in the smallest on-chain unit (wei, lamports, etc.). Maximum 100 characters.
asset_address: CustomTokenTransferSourceAssetAddressThe token contract address (EVM) or mint address (Solana) of the asset to transfer.
chain: StringThe blockchain network on which to perform the transfer. Supported chains include: ‘ethereum’, ‘base’, ‘arbitrum’, ‘polygon’, ‘solana’, and their respective testnets.