pub struct DeviceVerifyRequestBody {
pub action: DeviceVerifyAction,
pub user_code: String,
}Expand description
Request body for approving or denying a device authorization request. The user must be authenticated and belong to the target app.
JSON schema
{
"title": "DeviceVerifyRequestBody",
"description": "Request body for approving or denying a device
authorization request. The user must be authenticated and belong to the
target app.",
"type": "object",
"required": [
"action",
"user_code"
],
"properties": {
"action": {
"$ref": "#/components/schemas/DeviceVerifyAction"
},
"user_code": {
"description": "The user code displayed on the CLI device.",
"type": "string"
}
},
"x-stainless-model": "client_auth.device_verify_request_body"
}Fields
action: DeviceVerifyActionuser_code: StringThe user code displayed on the CLI device.