pub struct EarnIncentiveRewardsResponse {
pub rewards: Vec<EarnIncentiveRewardEntry>,
}Expand description
All incentive rewards for a wallet, with claimed and unclaimed amounts per token.
JSON schema
{
"title": "EarnIncentiveRewardsResponse",
"description": "All incentive rewards for a wallet, with claimed and
unclaimed amounts per token.",
"examples": [
{
"rewards": [
{
"amount_claimed": "1000000000000000000",
"amount_unclaimed": "500000000000000000",
"token_address": "0x0000000000000000000000000000000000000000",
"token_decimals": 18,
"token_symbol": "MORPHO"
}
]
}
],
"type": "object",
"required": [
"rewards"
],
"properties": {
"rewards": {
"description": "Reward tokens with their claimed and unclaimed
amounts.",
"type": "array",
"items": {
"$ref": "#/components/schemas/EarnIncentiveRewardEntry"
}
}
},
"x-stainless-model": "wallet_actions.earn_incentive_rewards_response"
}Fields
rewards: Vec<EarnIncentiveRewardEntry>Reward tokens with their claimed and unclaimed amounts.