pub struct EarnIncetiveClaimRewardEntry {
pub amount: String,
pub token_address: String,
pub token_decimals: Option<i64>,
pub token_symbol: String,
}Expand description
A specific reward token and amount associated with an earn incentive claim.
JSON schema
{
"title": "EarnIncetiveClaimRewardEntry",
"description": "A specific reward token and amount associated with an
earn incentive claim.",
"type": "object",
"required": [
"amount",
"token_address",
"token_symbol"
],
"properties": {
"amount": {
"description": "Claimable amount in base units.",
"type": "string"
},
"token_address": {
"description": "Address of the reward token.",
"type": "string"
},
"token_decimals": {
"description": "Number of decimal places for the reward token.",
"type": "integer"
},
"token_symbol": {
"description": "Symbol of the reward token (e.g. \"MORPHO\").",
"type": "string"
}
},
"x-stainless-model": "wallet_actions.earn_incetive_claim_reward_entry"
}Fields
amount: StringClaimable amount in base units.
token_address: StringAddress of the reward token.
token_decimals: Option<i64>Number of decimal places for the reward token.
token_symbol: StringSymbol of the reward token (e.g. “MORPHO”).