pub struct EthereumEarnPositionResponse {
pub asset: EarnAsset,
pub assets_in_vault: String,
pub shares_in_vault: String,
pub total_deposited: String,
pub total_withdrawn: String,
}Expand description
A wallet’s position in an earn vault.
JSON schema
{
"title": "EthereumEarnPositionResponse",
"description": "A wallet's position in an earn vault.",
"examples": [
{
"asset": {
"address": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
"decimals": 6,
"symbol": "usdc"
},
"assets_in_vault": "1050000",
"shares_in_vault": "1000000000000000000",
"total_deposited": "1000000",
"total_withdrawn": "0"
}
],
"type": "object",
"required": [
"asset",
"assets_in_vault",
"shares_in_vault",
"total_deposited",
"total_withdrawn"
],
"properties": {
"asset": {
"$ref": "#/components/schemas/EarnAsset"
},
"assets_in_vault": {
"description": "Current asset value in the vault (realtime from
ERC-4626), in smallest unit.",
"type": "string"
},
"shares_in_vault": {
"description": "Current vault shares held (realtime from
ERC-4626).",
"type": "string"
},
"total_deposited": {
"description": "Total amount deposited into the vault, in smallest
unit.",
"type": "string"
},
"total_withdrawn": {
"description": "Total amount withdrawn from the vault, in smallest
unit.",
"type": "string"
}
},
"x-stainless-model": "wallet_actions.ethereum_earn_position_response"
}Fields
asset: EarnAssetassets_in_vault: StringCurrent asset value in the vault (realtime from ERC-4626), in smallest unit.
Current vault shares held (realtime from ERC-4626).
total_deposited: StringTotal amount deposited into the vault, in smallest unit.
total_withdrawn: StringTotal amount withdrawn from the vault, in smallest unit.