pub struct EthereumYieldClaimIdInput {
pub id: String,
}Expand description
Input for fetching a yield reward claim by ID.
JSON schema
{
"title": "EthereumYieldClaimIdInput",
"description": "Input for fetching a yield reward claim by ID.",
"examples": [
{
"id": "a1b2c3d4-e5f6-7890-abcd-ef1234567890"
}
],
"type": "object",
"required": [
"id"
],
"properties": {
"id": {
"description": "The yield claim transaction ID.",
"type": "string"
}
},
"x-stainless-model": "yield.ethereum_yield_claim_id_input"
}Fields
id: StringThe yield claim transaction ID.