pub struct EthereumYieldClaimResponse {
pub caip2: EvmCaip2ChainId,
pub created_at: f64,
pub id: String,
pub rewards: Vec<EthereumYieldClaimReward>,
pub status: EthereumYieldClaimResponseStatus,
pub updated_at: f64,
}Expand description
Response from a yield reward claim operation.
JSON schema
{
"title": "EthereumYieldClaimResponse",
"description": "Response from a yield reward claim operation.",
"examples": [
{
"caip2": "eip155:8453",
"created_at": 1631573050000,
"id": "a1b2c3d4-e5f6-7890-abcd-ef1234567890",
"rewards": [
{
"amount": "115631364898103632676",
"token_address": "0x1234567890abcdef1234567890abcdef12345678",
"token_symbol": "MORPHO"
}
],
"status": "pending",
"updated_at": 1631573050000
}
],
"type": "object",
"required": [
"caip2",
"created_at",
"id",
"rewards",
"status",
"updated_at"
],
"properties": {
"caip2": {
"$ref": "#/components/schemas/EvmCaip2ChainId"
},
"created_at": {
"description": "Unix timestamp of when the claim was created, in
milliseconds.",
"type": "number"
},
"id": {
"description": "Privy transaction record ID for the claim
operation.",
"type": "string"
},
"rewards": {
"description": "List of reward tokens claimed.",
"type": "array",
"items": {
"$ref": "#/components/schemas/EthereumYieldClaimReward"
}
},
"status": {
"description": "The current status of the claim transaction.",
"type": "string",
"enum": [
"broadcasted",
"confirmed",
"execution_reverted",
"failed",
"finalized",
"pending",
"provider_error",
"replaced"
]
},
"updated_at": {
"description": "Unix timestamp of when the claim was last updated,
in milliseconds.",
"type": "number"
}
},
"x-stainless-model": "yield.ethereum_yield_claim_response"
}Fields
caip2: EvmCaip2ChainIdcreated_at: f64id: StringPrivy transaction record ID for the claim operation.
rewards: Vec<EthereumYieldClaimReward>List of reward tokens claimed.
status: EthereumYieldClaimResponseStatusThe current status of the claim transaction.
updated_at: f64Trait Implementations
Sourceimpl Clone for EthereumYieldClaimResponse
impl Clone for EthereumYieldClaimResponse
Sourcefn clone(&self) -> EthereumYieldClaimResponse
fn clone(&self) -> EthereumYieldClaimResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EthereumYieldClaimResponse
impl Debug for EthereumYieldClaimResponse
Sourceimpl<'de> Deserialize<'de> for EthereumYieldClaimResponse
impl<'de> Deserialize<'de> for EthereumYieldClaimResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&EthereumYieldClaimResponse> for EthereumYieldClaimResponse
impl From<&EthereumYieldClaimResponse> for EthereumYieldClaimResponse
Sourcefn from(value: &EthereumYieldClaimResponse) -> Self
fn from(value: &EthereumYieldClaimResponse) -> Self
Converts to this type from the input type.