pub struct EthereumYieldSweepResponse {
pub asset_amount: Option<String>,
pub created_at: f64,
pub id: String,
pub share_amount: Option<String>,
pub status: EthereumYieldSweepStatus,
pub type_: EthereumYieldSweepType,
pub updated_at: f64,
pub vault_id: String,
pub wallet_id: String,
}Expand description
A yield sweep record representing a deposit or withdrawal.
JSON schema
{
"title": "EthereumYieldSweepResponse",
"description": "A yield sweep record representing a deposit or
withdrawal.",
"examples": [
{
"asset_amount": "1000000",
"created_at": 1631573050000,
"id": "cm7oxq1el000e11o8iwp7d0d0",
"share_amount": "987654321",
"status": "pending",
"type": "deposit",
"updated_at": 1631573050000,
"vault_id": "cm7oxq1el000e11o8iwp7d0d0",
"wallet_id": "fmfdj6yqly31huorjqzq38zc"
}
],
"type": "object",
"required": [
"created_at",
"id",
"status",
"type",
"updated_at",
"vault_id",
"wallet_id"
],
"properties": {
"asset_amount": {
"description": "The amount of underlying assets involved. Set after
the sweep is confirmed on-chain.",
"type": "string"
},
"created_at": {
"description": "Unix timestamp of when the sweep was created, in
milliseconds.",
"type": "number"
},
"id": {
"description": "Unique identifier for the yield sweep.",
"type": "string"
},
"share_amount": {
"description": "The amount of vault shares involved. Set after the
sweep is confirmed on-chain.",
"type": "string"
},
"status": {
"$ref": "#/components/schemas/EthereumYieldSweepStatus"
},
"type": {
"$ref": "#/components/schemas/EthereumYieldSweepType"
},
"updated_at": {
"description": "Unix timestamp of when the sweep was last updated,
in milliseconds.",
"type": "number"
},
"vault_id": {
"description": "The ID of the vault involved in the sweep.",
"type": "string"
},
"wallet_id": {
"description": "The ID of the wallet involved in the sweep.",
"type": "string"
}
},
"x-stainless-model": "yield.ethereum_yield_sweep_response"
}Fields
asset_amount: Option<String>The amount of underlying assets involved. Set after the sweep is confirmed on-chain.
created_at: f64id: StringUnique identifier for the yield sweep.
The amount of vault shares involved. Set after the sweep is confirmed on-chain.
status: EthereumYieldSweepStatustype_: EthereumYieldSweepTypeupdated_at: f64vault_id: StringThe ID of the vault involved in the sweep.
wallet_id: StringThe ID of the wallet involved in the sweep.