pub struct EthereumYieldWithdrawInput {
pub asset_amount: EthereumYieldWithdrawInputAssetAmount,
pub vault_id: String,
}Expand description
Input for withdrawing assets from an ERC-4626 vault.
JSON schema
{
"title": "EthereumYieldWithdrawInput",
"description": "Input for withdrawing assets from an ERC-4626 vault.",
"examples": [
{
"asset_amount": "1000000",
"vault_id": "cm7oxq1el000e11o8iwp7d0d0"
}
],
"type": "object",
"required": [
"asset_amount",
"vault_id"
],
"properties": {
"asset_amount": {
"description": "The amount of the underlying asset to withdraw, in
the smallest unit (e.g., wei for ETH, 6 decimals for USDC). Must be a
non-negative integer string.",
"type": "string",
"maxLength": 78,
"minLength": 1,
"pattern": "^\\d+$"
},
"vault_id": {
"description": "The ID of the vault to withdraw from.",
"type": "string"
}
},
"x-stainless-model": "yield.ethereum_yield_withdraw_input"
}Fields
asset_amount: EthereumYieldWithdrawInputAssetAmountThe amount of the underlying asset to withdraw, in the smallest unit (e.g., wei for ETH, 6 decimals for USDC). Must be a non-negative integer string.
vault_id: StringThe ID of the vault to withdraw from.