pub struct EvmUserOperationWalletActionStep {
pub bundle_transaction_hash: Option<String>,
pub caip2: String,
pub entrypoint_version: EvmUserOperationWalletActionStepEntrypointVersion,
pub failure_reason: Option<FailureReason>,
pub status: EvmWalletActionStepStatus,
pub type_: EvmUserOperationWalletActionStepType,
pub user_operation_hash: Option<String>,
}Expand description
A wallet action step consisting of an EVM user operation.
JSON schema
{
"title": "EVMUserOperationWalletActionStep",
"description": "A wallet action step consisting of an EVM user
operation.",
"type": "object",
"required": [
"caip2",
"entrypoint_version",
"status",
"type"
],
"properties": {
"bundle_transaction_hash": {
"description": "Transaction hash of the bundle in which this user
operation was included. Null until included by a bundler.",
"type": "string"
},
"caip2": {
"description": "CAIP-2 network identifier, containing the chain ID
of the user operation.",
"type": "string"
},
"entrypoint_version": {
"description": "The entrypoint version of the user operation.",
"type": "string",
"enum": [
"0.6",
"0.7",
"0.8",
"0.9"
]
},
"failure_reason": {
"$ref": "#/components/schemas/FailureReason"
},
"status": {
"allOf": [
{
"$ref": "#/components/schemas/EVMWalletActionStepStatus"
},
{
"description": "User operation status."
}
]
},
"type": {
"type": "string",
"enum": [
"evm_user_operation"
]
},
"user_operation_hash": {
"description": "The user operation hash for this step. May change
while the step status is non-terminal.",
"type": "string"
}
},
"x-stainless-model":
"wallet_actions.evm_user_operation_wallet_action_step"
}Fields
bundle_transaction_hash: Option<String>Transaction hash of the bundle in which this user operation was included. Null until included by a bundler.
caip2: StringCAIP-2 network identifier, containing the chain ID of the user operation.
entrypoint_version: EvmUserOperationWalletActionStepEntrypointVersionThe entrypoint version of the user operation.
failure_reason: Option<FailureReason>status: EvmWalletActionStepStatustype_: EvmUserOperationWalletActionStepTypeuser_operation_hash: Option<String>The user operation hash for this step. May change while the step status is non-terminal.