pub struct FarcasterSignerInitPendingApproval {
pub public_key: String,
pub signer_approval_url: String,
pub status: FarcasterSignerInitPendingApprovalStatus,
}Expand description
A Farcaster signer init response when the signer is pending approval.
JSON schema
{
"title": "FarcasterSignerInitPendingApproval",
"description": "A Farcaster signer init response when the signer is
pending approval.",
"type": "object",
"required": [
"public_key",
"signer_approval_url",
"status"
],
"properties": {
"public_key": {
"type": "string"
},
"signer_approval_url": {
"type": "string"
},
"status": {
"type": "string",
"enum": [
"pending_approval"
]
}
},
"x-stainless-model":
"client_auth.farcaster_signer_init_pending_approval"
}Fields
public_key: Stringsigner_approval_url: Stringstatus: FarcasterSignerInitPendingApprovalStatusTrait Implementations
Sourceimpl Clone for FarcasterSignerInitPendingApproval
impl Clone for FarcasterSignerInitPendingApproval
Sourcefn clone(&self) -> FarcasterSignerInitPendingApproval
fn clone(&self) -> FarcasterSignerInitPendingApproval
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for FarcasterSignerInitPendingApproval
impl<'de> Deserialize<'de> for FarcasterSignerInitPendingApproval
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&FarcasterSignerInitPendingApproval> for FarcasterSignerInitPendingApproval
impl From<&FarcasterSignerInitPendingApproval> for FarcasterSignerInitPendingApproval
Sourcefn from(value: &FarcasterSignerInitPendingApproval) -> Self
fn from(value: &FarcasterSignerInitPendingApproval) -> Self
Converts to this type from the input type.
Sourceimpl From<FarcasterSignerInitPendingApproval> for FarcasterSignerInitResponseBody
impl From<FarcasterSignerInitPendingApproval> for FarcasterSignerInitResponseBody
Sourcefn from(value: FarcasterSignerInitPendingApproval) -> Self
fn from(value: FarcasterSignerInitPendingApproval) -> Self
Converts to this type from the input type.