pub struct FarcasterSignerRevoked {
pub fid: String,
pub public_key: String,
pub status: FarcasterSignerRevokedStatus,
}Expand description
A Farcaster signer response when the signer has been revoked.
JSON schema
{
"title": "FarcasterSignerRevoked",
"description": "A Farcaster signer response when the signer has been
revoked.",
"type": "object",
"required": [
"fid",
"public_key",
"status"
],
"properties": {
"fid": {
"type": "string"
},
"public_key": {
"type": "string"
},
"status": {
"type": "string",
"enum": [
"revoked"
]
}
},
"x-stainless-model": "client_auth.farcaster_signer_revoked"
}Fields
fid: Stringpublic_key: Stringstatus: FarcasterSignerRevokedStatusTrait Implementations
Sourceimpl Clone for FarcasterSignerRevoked
impl Clone for FarcasterSignerRevoked
Sourcefn clone(&self) -> FarcasterSignerRevoked
fn clone(&self) -> FarcasterSignerRevoked
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FarcasterSignerRevoked
impl Debug for FarcasterSignerRevoked
Sourceimpl<'de> Deserialize<'de> for FarcasterSignerRevoked
impl<'de> Deserialize<'de> for FarcasterSignerRevoked
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&FarcasterSignerRevoked> for FarcasterSignerRevoked
impl From<&FarcasterSignerRevoked> for FarcasterSignerRevoked
Sourcefn from(value: &FarcasterSignerRevoked) -> Self
fn from(value: &FarcasterSignerRevoked) -> Self
Converts to this type from the input type.
Sourceimpl From<FarcasterSignerRevoked> for FarcasterSignerInitResponseBody
impl From<FarcasterSignerRevoked> for FarcasterSignerInitResponseBody
Sourcefn from(value: FarcasterSignerRevoked) -> Self
fn from(value: FarcasterSignerRevoked) -> Self
Converts to this type from the input type.
Sourceimpl From<FarcasterSignerRevoked> for FarcasterSignerStatusResponseBody
impl From<FarcasterSignerRevoked> for FarcasterSignerStatusResponseBody
Sourcefn from(value: FarcasterSignerRevoked) -> Self
fn from(value: FarcasterSignerRevoked) -> Self
Converts to this type from the input type.