pub struct FarcasterSignerStatusPendingApproval {
pub public_key: String,
pub status: FarcasterSignerStatusPendingApprovalStatus,
}Expand description
A Farcaster signer status response when the signer is pending approval.
JSON schema
{
"title": "FarcasterSignerStatusPendingApproval",
"description": "A Farcaster signer status response when the signer is
pending approval.",
"type": "object",
"required": [
"public_key",
"status"
],
"properties": {
"public_key": {
"type": "string"
},
"status": {
"type": "string",
"enum": [
"pending_approval"
]
}
},
"x-stainless-model":
"client_auth.farcaster_signer_status_pending_approval"
}Fields
public_key: Stringstatus: FarcasterSignerStatusPendingApprovalStatusTrait Implementations
Sourceimpl Clone for FarcasterSignerStatusPendingApproval
impl Clone for FarcasterSignerStatusPendingApproval
Sourcefn clone(&self) -> FarcasterSignerStatusPendingApproval
fn clone(&self) -> FarcasterSignerStatusPendingApproval
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for FarcasterSignerStatusPendingApproval
impl<'de> Deserialize<'de> for FarcasterSignerStatusPendingApproval
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&FarcasterSignerStatusPendingApproval> for FarcasterSignerStatusPendingApproval
impl From<&FarcasterSignerStatusPendingApproval> for FarcasterSignerStatusPendingApproval
Sourcefn from(value: &FarcasterSignerStatusPendingApproval) -> Self
fn from(value: &FarcasterSignerStatusPendingApproval) -> Self
Converts to this type from the input type.
Sourceimpl From<FarcasterSignerStatusPendingApproval> for FarcasterSignerStatusResponseBody
impl From<FarcasterSignerStatusPendingApproval> for FarcasterSignerStatusResponseBody
Sourcefn from(value: FarcasterSignerStatusPendingApproval) -> Self
fn from(value: FarcasterSignerStatusPendingApproval) -> Self
Converts to this type from the input type.