pub struct FarcasterV2InitInput(pub Map<String, Value>);Expand description
Input for initiating a Farcaster V2 connection.
JSON schema
{
"title": "FarcasterV2InitInput",
"description": "Input for initiating a Farcaster V2 connection.",
"type": "object",
"x-stainless-empty-object": true,
"x-stainless-model": "client_auth.farcaster_v_2_init_input"
}Tuple Fields
0: Map<String, Value>Methods from Deref<Target = Map<String, Value>>
Sourcepub fn get<Q>(&self, key: &Q) -> Option<&Value>
pub fn get<Q>(&self, key: &Q) -> Option<&Value>
Returns a reference to the value corresponding to the key.
The key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.
Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
pub fn contains_key<Q>(&self, key: &Q) -> bool
Returns true if the map contains a value for the specified key.
The key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.