pub struct GasSpendRequestBody {
pub end_timestamp: f64,
pub start_timestamp: f64,
pub wallet_ids: Vec<String>,
}Expand description
Query parameters for getting gas spend for a set of wallets. The time
range from start_timestamp to end_timestamp must not exceed 30 days.
JSON schema
{
"title": "GasSpendRequestBody",
"description": "Query parameters for getting gas spend for a set of
wallets. The time range from `start_timestamp` to `end_timestamp` must
not exceed 30 days.",
"examples": [
{
"end_timestamp": 1700086400000,
"start_timestamp": 1700000000000,
"wallet_ids": [
"fmfdj6yqly31huorjqzq38zc"
]
}
],
"type": "object",
"required": [
"end_timestamp",
"start_timestamp",
"wallet_ids"
],
"properties": {
"end_timestamp": {
"description": "Unix timestamp in milliseconds, exclusive. Must be
greater than or equal to `start_timestamp`, and the range from
`start_timestamp` to `end_timestamp` must not exceed 30 days.",
"type": "number"
},
"start_timestamp": {
"description": "Unix timestamp in milliseconds, inclusive. Must be
less than or equal to `end_timestamp`, and the range from
`start_timestamp` to `end_timestamp` must not exceed 30 days.",
"type": "number"
},
"wallet_ids": {
"description": "List of wallet IDs to query gas spend for. Maximum
100.",
"type": "array",
"items": {
"type": "string"
},
"maxItems": 100,
"minItems": 1
}
},
"x-stainless-model": "apps.gas_spend_request_body"
}Fields
end_timestamp: f64start_timestamp: f64wallet_ids: Vec<String>List of wallet IDs to query gas spend for. Maximum 100.