pub struct GasSpendResponseBody {
pub currency: GasSpendCurrency,
pub value: String,
}Expand description
Aggregated Privy gas credits charged for a set of wallets over a time range.
JSON schema
{
"title": "GasSpendResponseBody",
"description": "Aggregated Privy gas credits charged for a set of
wallets over a time range.",
"examples": [
{
"currency": "usd",
"value": "12.345678"
}
],
"type": "object",
"required": [
"currency",
"value"
],
"properties": {
"currency": {
"allOf": [
{
"$ref": "#/components/schemas/GasSpendCurrency"
},
{
"description": "Currency represented by the value."
}
]
},
"value": {
"description": "Total Privy credits charged as a decimal string.",
"type": "string"
}
},
"x-stainless-model": "apps.gas_spend_response_body"
}Fields
currency: GasSpendCurrencyvalue: StringTotal Privy credits charged as a decimal string.