pub struct GetByWalletAddressRequestBody {
pub address: Address,
}Expand description
Request body for looking up a wallet by its blockchain address.
JSON schema
{
"title": "GetByWalletAddressRequestBody",
"description": "Request body for looking up a wallet by its blockchain
address.",
"examples": [
{
"address": "0xF1DBff66C993EE895C8cb176c30b07A559d76496"
}
],
"type": "object",
"required": [
"address"
],
"properties": {
"address": {
"allOf": [
{
"$ref": "#/components/schemas/Address"
},
{
"description": "The blockchain address of the wallet to look
up."
}
]
}
},
"x-stainless-model": "wallets.get_by_wallet_address_request_body"
}Fields
address: AddressTrait Implementations
Sourceimpl Clone for GetByWalletAddressRequestBody
impl Clone for GetByWalletAddressRequestBody
Sourcefn clone(&self) -> GetByWalletAddressRequestBody
fn clone(&self) -> GetByWalletAddressRequestBody
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for GetByWalletAddressRequestBody
impl<'de> Deserialize<'de> for GetByWalletAddressRequestBody
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&GetByWalletAddressRequestBody> for GetByWalletAddressRequestBody
impl From<&GetByWalletAddressRequestBody> for GetByWalletAddressRequestBody
Sourcefn from(value: &GetByWalletAddressRequestBody) -> Self
fn from(value: &GetByWalletAddressRequestBody) -> Self
Converts to this type from the input type.