pub struct GetFiatOnrampUrlInput {
pub destination: FiatOnrampDestination,
pub payment_method: String,
pub provider: FiatOnrampProvider,
pub redirect_url: Option<String>,
pub source: FiatOnrampSource,
pub sub_provider: Option<String>,
}Expand description
The request input for getting a fiat onramp provider session URL.
JSON schema
{
"title": "GetFiatOnrampUrlInput",
"description": "The request input for getting a fiat onramp provider
session URL.",
"examples": [
{
"destination": {
"address": "0x1234567890abcdef1234567890abcdef12345678",
"asset": "USDC",
"chain": "eip155:42161"
},
"payment_method": "CREDIT_DEBIT_CARD",
"provider": "meld",
"source": {
"amount": "100.03",
"asset": "USD"
},
"sub_provider": "TRANSAK"
}
],
"type": "object",
"required": [
"destination",
"payment_method",
"provider",
"source"
],
"properties": {
"destination": {
"$ref": "#/components/schemas/FiatOnrampDestination"
},
"payment_method": {
"type": "string"
},
"provider": {
"$ref": "#/components/schemas/FiatOnrampProvider"
},
"redirect_url": {
"type": "string",
"format": "uri"
},
"source": {
"$ref": "#/components/schemas/FiatOnrampSource"
},
"sub_provider": {
"type": "string"
}
},
"x-stainless-model": "onramps.get_fiat_onramp_url_input"
}Fields
destination: FiatOnrampDestinationpayment_method: Stringprovider: FiatOnrampProviderredirect_url: Option<String>source: FiatOnrampSourcesub_provider: Option<String>Trait Implementations
Sourceimpl Clone for GetFiatOnrampUrlInput
impl Clone for GetFiatOnrampUrlInput
Sourcefn clone(&self) -> GetFiatOnrampUrlInput
fn clone(&self) -> GetFiatOnrampUrlInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetFiatOnrampUrlInput
impl Debug for GetFiatOnrampUrlInput
Sourceimpl<'de> Deserialize<'de> for GetFiatOnrampUrlInput
impl<'de> Deserialize<'de> for GetFiatOnrampUrlInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&GetFiatOnrampUrlInput> for GetFiatOnrampUrlInput
impl From<&GetFiatOnrampUrlInput> for GetFiatOnrampUrlInput
Sourcefn from(value: &GetFiatOnrampUrlInput) -> Self
fn from(value: &GetFiatOnrampUrlInput) -> Self
Converts to this type from the input type.