pub struct IntentAuthorizedWebhookPayload {
pub authorized_at: f64,
pub created_at: f64,
pub created_by_display_name: Option<String>,
pub created_by_id: Option<String>,
pub expires_at: f64,
pub intent_id: String,
pub intent_type: IntentType,
pub member: IntentAuthorizationKeyQuorumMember,
pub status: String,
pub type_: IntentAuthorizedWebhookPayloadType,
}Expand description
Payload for the intent.authorized webhook event.
JSON schema
{
"title": "IntentAuthorizedWebhookPayload",
"description": "Payload for the intent.authorized webhook event.",
"type": "object",
"required": [
"authorized_at",
"created_at",
"expires_at",
"intent_id",
"intent_type",
"member",
"status",
"type"
],
"properties": {
"authorized_at": {
"description": "Unix timestamp when the authorization was
recorded.",
"type": "number"
},
"created_at": {
"description": "Unix timestamp when the intent was created.",
"type": "number"
},
"created_by_display_name": {
"description": "Display name of the user who created the intent.",
"type": "string"
},
"created_by_id": {
"description": "The ID of the user who created the intent.",
"type": "string"
},
"expires_at": {
"description": "Unix timestamp when the intent expires.",
"type": "number"
},
"intent_id": {
"description": "The unique ID of the intent.",
"type": "string"
},
"intent_type": {
"$ref": "#/components/schemas/IntentType"
},
"member": {
"allOf": [
{
"$ref":
"#/components/schemas/IntentAuthorizationKeyQuorumMember"
},
{
"description": "The team member who provided this authorization
signature."
}
]
},
"status": {
"description": "The current status of the intent.",
"type": "string"
},
"type": {
"description": "The type of webhook event.",
"type": "string",
"enum": [
"intent.authorized"
]
}
},
"x-stainless-model": "webhooks.intent_authorized_webhook_payload"
}Fields
created_at: f64created_by_display_name: Option<String>Display name of the user who created the intent.
created_by_id: Option<String>The ID of the user who created the intent.
expires_at: f64intent_id: StringThe unique ID of the intent.
intent_type: IntentTypemember: IntentAuthorizationKeyQuorumMemberstatus: StringThe current status of the intent.
type_: IntentAuthorizedWebhookPayloadTypeThe type of webhook event.