pub struct IntentBinding {
pub intent_id: String,
pub type_: IntentBindingType,
}Expand description
A binding that scopes a user signing key to a specific intent.
JSON schema
{
"title": "IntentBinding",
"description": "A binding that scopes a user signing key to a specific
intent.",
"type": "object",
"required": [
"intentId",
"type"
],
"properties": {
"intentId": {
"type": "string"
},
"type": {
"type": "string",
"enum": [
"intent"
]
}
},
"x-stainless-model": "wallets.intent_binding"
}Fields
intent_id: Stringtype_: IntentBindingTypeTrait Implementations
Sourceimpl Clone for IntentBinding
impl Clone for IntentBinding
Sourcefn clone(&self) -> IntentBinding
fn clone(&self) -> IntentBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IntentBinding
impl Debug for IntentBinding
Sourceimpl<'de> Deserialize<'de> for IntentBinding
impl<'de> Deserialize<'de> for IntentBinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&IntentBinding> for IntentBinding
impl From<&IntentBinding> for IntentBinding
Sourcefn from(value: &IntentBinding) -> Self
fn from(value: &IntentBinding) -> Self
Converts to this type from the input type.
Sourceimpl From<IntentBinding> for UserSigningKeyBinding
impl From<IntentBinding> for UserSigningKeyBinding
Sourcefn from(value: IntentBinding) -> Self
fn from(value: IntentBinding) -> Self
Converts to this type from the input type.
Sourceimpl From<UserSigningKeyBinding> for IntentBinding
impl From<UserSigningKeyBinding> for IntentBinding
Sourcefn from(value: UserSigningKeyBinding) -> Self
fn from(value: UserSigningKeyBinding) -> Self
Converts to this type from the input type.