pub struct IntentCreatedWebhookPayload {
pub authorization_details: Vec<IntentAuthorization>,
pub created_at: f64,
pub created_by_display_name: Option<String>,
pub created_by_id: Option<String>,
pub expires_at: f64,
pub intent_id: String,
pub intent_type: IntentType,
pub status: String,
pub type_: IntentCreatedWebhookPayloadType,
}Expand description
Payload for the intent.created webhook event.
JSON schema
{
"title": "IntentCreatedWebhookPayload",
"description": "Payload for the intent.created webhook event.",
"type": "object",
"required": [
"created_at",
"expires_at",
"intent_id",
"intent_type",
"status",
"type"
],
"properties": {
"authorization_details": {
"description": "Key quorums that can authorize this intent.",
"type": "array",
"items": {
"$ref": "#/components/schemas/IntentAuthorization"
}
},
"created_at": {
"description": "Unix timestamp when the intent was created.",
"type": "number"
},
"created_by_display_name": {
"description": "Display name of the user who created the intent.",
"type": "string"
},
"created_by_id": {
"description": "The ID of the user who created the intent.",
"type": "string"
},
"expires_at": {
"description": "Unix timestamp when the intent expires.",
"type": "number"
},
"intent_id": {
"description": "The unique ID of the intent.",
"type": "string"
},
"intent_type": {
"$ref": "#/components/schemas/IntentType"
},
"status": {
"description": "The current status of the intent.",
"type": "string"
},
"type": {
"description": "The type of webhook event.",
"type": "string",
"enum": [
"intent.created"
]
}
},
"x-stainless-model": "webhooks.intent_created_webhook_payload"
}Fields
Key quorums that can authorize this intent.
created_at: f64created_by_display_name: Option<String>Display name of the user who created the intent.
created_by_id: Option<String>The ID of the user who created the intent.
expires_at: f64intent_id: StringThe unique ID of the intent.
intent_type: IntentTypestatus: StringThe current status of the intent.
type_: IntentCreatedWebhookPayloadTypeThe type of webhook event.