pub struct IntentCreationHeaders {
pub privy_app_id: String,
pub privy_request_expiry: Option<String>,
}Expand description
Headers required to create an intent.
JSON schema
{
"title": "IntentCreationHeaders",
"description": "Headers required to create an intent.",
"type": "object",
"required": [
"privy-app-id"
],
"properties": {
"privy-app-id": {
"description": "ID of your Privy app.",
"type": "string"
},
"privy-request-expiry": {
"description": "Request expiry. Value is a Unix timestamp in
milliseconds representing the deadline by which the request must be
processed.",
"type": "string"
}
},
"x-stainless-model": "intents.intent_creation_headers"
}Fields
privy_app_id: StringID of your Privy app.
privy_request_expiry: Option<String>Request expiry. Value is a Unix timestamp in milliseconds representing the deadline by which the request must be processed.