pub struct IntentExecutedWebhookPayload {
pub action_result: BaseActionResult,
pub created_at: f64,
pub created_by_display_name: Option<String>,
pub created_by_id: Option<String>,
pub expires_at: f64,
pub intent_id: String,
pub intent_type: IntentType,
pub status: String,
pub type_: IntentExecutedWebhookPayloadType,
}Expand description
Payload for the intent.executed webhook event.
JSON schema
{
"title": "IntentExecutedWebhookPayload",
"description": "Payload for the intent.executed webhook event.",
"type": "object",
"required": [
"action_result",
"created_at",
"expires_at",
"intent_id",
"intent_type",
"status",
"type"
],
"properties": {
"action_result": {
"title": "BaseActionResult",
"description": "Result of the successful intent execution.",
"allOf": [
{
"$ref": "#/components/schemas/BaseActionResult"
},
{
"type": "object",
"properties": {
"response_body": {
"description": "Response from the execution."
}
}
}
],
"x-stainless-model": "intents.base_action_result"
},
"created_at": {
"description": "Unix timestamp when the intent was created.",
"type": "number"
},
"created_by_display_name": {
"description": "Display name of the user who created the intent.",
"type": "string"
},
"created_by_id": {
"description": "The ID of the user who created the intent.",
"type": "string"
},
"expires_at": {
"description": "Unix timestamp when the intent expires.",
"type": "number"
},
"intent_id": {
"description": "The unique ID of the intent.",
"type": "string"
},
"intent_type": {
"$ref": "#/components/schemas/IntentType"
},
"status": {
"description": "The current status of the intent.",
"type": "string"
},
"type": {
"description": "The type of webhook event.",
"type": "string",
"enum": [
"intent.executed"
]
}
},
"x-stainless-model": "webhooks.intent_executed_webhook_payload"
}Fields
action_result: BaseActionResultcreated_at: f64created_by_display_name: Option<String>Display name of the user who created the intent.
created_by_id: Option<String>The ID of the user who created the intent.
expires_at: f64intent_id: StringThe unique ID of the intent.
intent_type: IntentTypestatus: StringThe current status of the intent.
type_: IntentExecutedWebhookPayloadTypeThe type of webhook event.