pub struct IntentRejectedWebhookPayload {
pub created_at: f64,
pub created_by_display_name: Option<String>,
pub created_by_id: Option<String>,
pub expires_at: f64,
pub intent_id: String,
pub intent_type: IntentType,
pub rejected_at: f64,
pub status: String,
pub type_: IntentRejectedWebhookPayloadType,
}Expand description
Payload for the intent.rejected webhook event.
JSON schema
{
"title": "IntentRejectedWebhookPayload",
"description": "Payload for the intent.rejected webhook event.",
"type": "object",
"required": [
"created_at",
"expires_at",
"intent_id",
"intent_type",
"rejected_at",
"status",
"type"
],
"properties": {
"created_at": {
"description": "Unix timestamp when the intent was created.",
"type": "number"
},
"created_by_display_name": {
"description": "Display name of the user who created the intent.",
"type": "string"
},
"created_by_id": {
"description": "The ID of the user who created the intent.",
"type": "string"
},
"expires_at": {
"description": "Unix timestamp when the intent expires.",
"type": "number"
},
"intent_id": {
"description": "The unique ID of the intent.",
"type": "string"
},
"intent_type": {
"$ref": "#/components/schemas/IntentType"
},
"rejected_at": {
"description": "Unix timestamp when the intent was rejected.",
"type": "number"
},
"status": {
"description": "The current status of the intent.",
"type": "string"
},
"type": {
"description": "The type of webhook event.",
"type": "string",
"enum": [
"intent.rejected"
]
}
},
"x-stainless-model": "webhooks.intent_rejected_webhook_payload"
}Fields
created_at: f64created_by_display_name: Option<String>Display name of the user who created the intent.
created_by_id: Option<String>The ID of the user who created the intent.
expires_at: f64intent_id: StringThe unique ID of the intent.
intent_type: IntentTyperejected_at: f64status: StringThe current status of the intent.
type_: IntentRejectedWebhookPayloadTypeThe type of webhook event.