pub struct KeyQuorumAuthorizationHeaders {
pub privy_app_id: String,
pub privy_authorization_signature: Option<String>,
pub privy_request_expiry: Option<String>,
}Expand description
Headers required to authorize modifications to key quorums.
JSON schema
{
"title": "KeyQuorumAuthorizationHeaders",
"description": "Headers required to authorize modifications to key
quorums.",
"type": "object",
"required": [
"privy-app-id"
],
"properties": {
"privy-app-id": {
"description": "ID of your Privy app.",
"type": "string"
},
"privy-authorization-signature": {
"description": "Request authorization signature. If multiple
signatures are required, they should be comma separated.",
"type": "string"
},
"privy-request-expiry": {
"description": "Request expiry. Value is a Unix timestamp in
milliseconds representing the deadline by which the request must be
processed.",
"type": "string"
}
},
"x-stainless-model": "key_quorums.key_quorum_authorization_headers"
}Fields
privy_app_id: StringID of your Privy app.
Request authorization signature. If multiple signatures are required, they should be comma separated.
privy_request_expiry: Option<String>Request expiry. Value is a Unix timestamp in milliseconds representing the deadline by which the request must be processed.