pub struct KeyQuorumCreateRequestBody {
pub authorization_threshold: Option<f64>,
pub display_name: Option<KeyQuorumCreateRequestBodyDisplayName>,
pub key_quorum_ids: Vec<String>,
pub public_keys: Vec<String>,
pub user_ids: Vec<String>,
}Expand description
Request input for creating a key quorum. At least one of user_ids,
public_keys, or key_quorum_ids is required.
JSON schema
{
"title": "KeyQuorumCreateRequestBody",
"description": "Request input for creating a key quorum. At least one
of `user_ids`, `public_keys`, or `key_quorum_ids` is required.",
"type": "object",
"properties": {
"authorization_threshold": {
"description": "The number of keys that must sign for an action to
be valid. Must be less than or equal to total number of key quorum
members.",
"type": "number",
"minimum": 1.0
},
"display_name": {
"type": "string",
"maxLength": 50
},
"key_quorum_ids": {
"description": "List of key quorum IDs that should be members of
this key quorum. Key quorums can only be nested 1 level deep. At least
one of `user_ids`, `public_keys`, or `key_quorum_ids` is required.",
"type": "array",
"items": {
"type": "string"
},
"maxItems": 5,
"minItems": 1
},
"public_keys": {
"description": "List of P-256 public keys of the keys that should
be authorized to sign on the key quorum, in base64-encoded DER format.
At least one of `user_ids`, `public_keys`, or `key_quorum_ids` is
required.",
"type": "array",
"items": {
"type": "string"
},
"minItems": 1
},
"user_ids": {
"description": "List of user IDs of the users that should be
authorized to sign on the key quorum. At least one of `user_ids`,
`public_keys`, or `key_quorum_ids` is required.",
"type": "array",
"items": {
"type": "string"
},
"minItems": 1
}
},
"x-stainless-model": "key_quorums.key_quorum_create_request_body"
}Fields
display_name: Option<KeyQuorumCreateRequestBodyDisplayName>key_quorum_ids: Vec<String>List of key quorum IDs that should be members of this key quorum.
Key quorums can only be nested 1 level deep. At least one of
user_ids, public_keys, or key_quorum_ids is required.
public_keys: Vec<String>List of P-256 public keys of the keys that should be authorized to
sign on the key quorum, in base64-encoded DER format. At least one
of user_ids, public_keys, or key_quorum_ids is required.
user_ids: Vec<String>List of user IDs of the users that should be authorized to sign on
the key quorum. At least one of user_ids, public_keys, or
key_quorum_ids is required.