pub struct KeyQuorumIntentResponse {Show 16 fields
pub action_result: Option<BaseActionResult>,
pub authorization_details: Vec<IntentAuthorization>,
pub created_at: f64,
pub created_by_display_name: String,
pub created_by_id: Option<String>,
pub current_resource_data: Option<KeyQuorum>,
pub custom_expiry: bool,
pub dismissal_reason: Option<String>,
pub dismissed_at: Option<f64>,
pub expires_at: f64,
pub intent_id: String,
pub intent_type: KeyQuorumIntentResponseIntentType,
pub rejected_at: Option<f64>,
pub request_details: KeyQuorumIntentResponseRequestDetails,
pub resource_id: String,
pub status: IntentStatus,
}Expand description
Response for a key quorum intent
JSON schema
{
"title": "KeyQuorumIntentResponse",
"description": "Response for a key quorum intent",
"allOf": [
{
"$ref": "#/components/schemas/BaseIntentResponse"
},
{
"type": "object",
"required": [
"intent_type",
"request_details"
],
"properties": {
"action_result": {
"title": "BaseActionResult",
"description": "Result of key quorum update execution (only
present if status is 'executed' or 'failed')",
"allOf": [
{
"$ref": "#/components/schemas/BaseActionResult"
},
{
"type": "object",
"required": [
"prior_state",
"response_body"
],
"properties": {
"prior_state": {
"allOf": [
{
"$ref": "#/components/schemas/KeyQuorum"
},
{
"description": "State of the key quorum immediately
before execution"
}
]
},
"response_body": {
"$ref": "#/components/schemas/KeyQuorum"
}
}
}
],
"x-stainless-model": "intents.base_action_result"
},
"current_resource_data": {
"allOf": [
{
"$ref": "#/components/schemas/KeyQuorum"
},
{
"description": "Current state of the key quorum before any changes. If undefined, the resource was deleted and no longer exists"
}
]
},
"intent_type": {
"type": "string",
"enum": [
"KEY_QUORUM"
]
},
"request_details": {
"description": "The original key quorum update request that
would be sent to the key quorum endpoint",
"type": "object",
"required": [
"body",
"method",
"url"
],
"properties": {
"body": {
"allOf": [
{
"$ref":
"#/components/schemas/KeyQuorumUpdateRequestBody"
},
{}
]
},
"method": {
"type": "string",
"enum": [
"PATCH"
]
},
"url": {
"type": "string"
}
}
}
}
}
],
"x-stainless-model": "intents.key_quorum_intent_response"
}Fields
action_result: Option<BaseActionResult>Detailed authorization information including key quorum members, thresholds, and signature status
created_at: f64created_by_display_name: StringDisplay name of the user who created the intent
created_by_id: Option<String>ID of the user who created the intent. If undefined, the intent was created using the app secret
current_resource_data: Option<KeyQuorum>custom_expiry: boolWhether this intent has a custom expiry time set by the client. If false, the intent expires after a default duration.
dismissal_reason: Option<String>Human-readable reason for dismissal, present when status is ‘dismissed’
dismissed_at: Option<f64>expires_at: f64intent_id: StringUnique ID for the intent
intent_type: KeyQuorumIntentResponseIntentTyperejected_at: Option<f64>request_details: KeyQuorumIntentResponseRequestDetailsresource_id: StringID of the resource being modified (wallet_id, policy_id, etc)
status: IntentStatusTrait Implementations
Sourceimpl Clone for KeyQuorumIntentResponse
impl Clone for KeyQuorumIntentResponse
Sourcefn clone(&self) -> KeyQuorumIntentResponse
fn clone(&self) -> KeyQuorumIntentResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KeyQuorumIntentResponse
impl Debug for KeyQuorumIntentResponse
Sourceimpl<'de> Deserialize<'de> for KeyQuorumIntentResponse
impl<'de> Deserialize<'de> for KeyQuorumIntentResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&KeyQuorumIntentResponse> for KeyQuorumIntentResponse
impl From<&KeyQuorumIntentResponse> for KeyQuorumIntentResponse
Sourcefn from(value: &KeyQuorumIntentResponse) -> Self
fn from(value: &KeyQuorumIntentResponse) -> Self
Converts to this type from the input type.
Sourceimpl From<KeyQuorumIntentResponse> for IntentResponse
impl From<KeyQuorumIntentResponse> for IntentResponse
Sourcefn from(value: KeyQuorumIntentResponse) -> Self
fn from(value: KeyQuorumIntentResponse) -> Self
Converts to this type from the input type.