pub struct KeyQuorumIntentResponseRequestDetails {
pub body: KeyQuorumIntentResponseRequestDetailsBody,
pub method: KeyQuorumIntentResponseRequestDetailsMethod,
pub url: String,
}Expand description
The original key quorum update request that would be sent to the key quorum endpoint
JSON schema
{
"description": "The original key quorum update request that would be
sent to the key quorum endpoint",
"type": "object",
"required": [
"body",
"method",
"url"
],
"properties": {
"body": {
"type": "object",
"properties": {
"authorization_threshold": {
"description": "The number of keys that must sign for an action
to be valid. Must be less than or equal to total number of key quorum
members.",
"type": "number",
"minimum": 1.0
},
"display_name": {
"type": "string",
"maxLength": 50
},
"public_keys": {
"description": "List of P-256 public keys of the keys that
should be authorized to sign on the key quorum, in base64-encoded DER
format.",
"type": "array",
"items": {
"type": "string"
}
},
"user_ids": {
"description": "List of user IDs of the users that should be
authorized to sign on the key quorum.",
"type": "array",
"items": {
"type": "string"
}
}
}
},
"method": {
"type": "string",
"enum": [
"PATCH"
]
},
"url": {
"type": "string"
}
}
}Fields
body: KeyQuorumIntentResponseRequestDetailsBodymethod: KeyQuorumIntentResponseRequestDetailsMethodurl: StringTrait Implementations
Sourceimpl Clone for KeyQuorumIntentResponseRequestDetails
impl Clone for KeyQuorumIntentResponseRequestDetails
Sourcefn clone(&self) -> KeyQuorumIntentResponseRequestDetails
fn clone(&self) -> KeyQuorumIntentResponseRequestDetails
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for KeyQuorumIntentResponseRequestDetails
impl<'de> Deserialize<'de> for KeyQuorumIntentResponseRequestDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&KeyQuorumIntentResponseRequestDetails> for KeyQuorumIntentResponseRequestDetails
impl From<&KeyQuorumIntentResponseRequestDetails> for KeyQuorumIntentResponseRequestDetails
Sourcefn from(value: &KeyQuorumIntentResponseRequestDetails) -> Self
fn from(value: &KeyQuorumIntentResponseRequestDetails) -> Self
Converts to this type from the input type.