pub struct KeyQuorumIntentResponseRequestDetailsBody {
pub authorization_threshold: Option<f64>,
pub display_name: Option<KeyQuorumIntentResponseRequestDetailsBodyDisplayName>,
pub public_keys: Vec<String>,
pub user_ids: Vec<String>,
}Expand description
KeyQuorumIntentResponseRequestDetailsBody
JSON schema
{
"type": "object",
"properties": {
"authorization_threshold": {
"description": "The number of keys that must sign for an action to
be valid. Must be less than or equal to total number of key quorum
members.",
"type": "number",
"minimum": 1.0
},
"display_name": {
"type": "string",
"maxLength": 50
},
"public_keys": {
"description": "List of P-256 public keys of the keys that should be authorized to sign on the key quorum, in base64-encoded DER format.",
"type": "array",
"items": {
"type": "string"
}
},
"user_ids": {
"description": "List of user IDs of the users that should be
authorized to sign on the key quorum.",
"type": "array",
"items": {
"type": "string"
}
}
}
}Fields
display_name: Option<KeyQuorumIntentResponseRequestDetailsBodyDisplayName>public_keys: Vec<String>List of P-256 public keys of the keys that should be authorized to sign on the key quorum, in base64-encoded DER format.
user_ids: Vec<String>List of user IDs of the users that should be authorized to sign on the key quorum.