pub struct KeyQuorumUpdateRequestBody {
pub authorization_threshold: Option<f64>,
pub display_name: Option<KeyQuorumUpdateRequestBodyDisplayName>,
pub key_quorum_ids: Vec<String>,
pub public_keys: Vec<String>,
pub user_ids: Vec<String>,
}Expand description
Request input for updating an existing key quorum. At least one field must be provided.
JSON schema
{
"title": "KeyQuorumUpdateRequestBody",
"description": "Request input for updating an existing key quorum. At
least one field must be provided.",
"type": "object",
"properties": {
"authorization_threshold": {
"description": "The number of keys that must sign for an action to
be valid. Must be less than or equal to total number of key quorum
members.",
"type": "number"
},
"display_name": {
"type": "string",
"maxLength": 50
},
"key_quorum_ids": {
"description": "List of key quorum IDs that should be members of
this key quorum. Key quorums can only be nested 1 level deep.",
"type": "array",
"items": {
"type": "string"
},
"maxItems": 5
},
"public_keys": {
"description": "List of P-256 public keys of the keys that should be authorized to sign on the key quorum, in base64-encoded DER format.",
"type": "array",
"items": {
"type": "string"
}
},
"user_ids": {
"description": "List of user IDs of the users that should be
authorized to sign on the key quorum.",
"type": "array",
"items": {
"type": "string"
}
}
},
"x-stainless-model": "key_quorums.key_quorum_update_request_body"
}Fields
display_name: Option<KeyQuorumUpdateRequestBodyDisplayName>key_quorum_ids: Vec<String>List of key quorum IDs that should be members of this key quorum. Key quorums can only be nested 1 level deep.
public_keys: Vec<String>List of P-256 public keys of the keys that should be authorized to sign on the key quorum, in base64-encoded DER format.
user_ids: Vec<String>List of user IDs of the users that should be authorized to sign on the key quorum.