pub struct KrakenEmbedCurrentDayPnl {
pub pnl: KrakenEmbedCurrentDayPnlPnl,
pub since: DateTime<Utc>,
}Expand description
Current day profit and loss for a portfolio, calculated from the most recent available balance.
JSON schema
{
"title": "KrakenEmbedCurrentDayPnl",
"description": "Current day profit and loss for a portfolio, calculated
from the most recent available balance.",
"type": "object",
"required": [
"pnl",
"since"
],
"properties": {
"pnl": {
"type": "string",
"maxLength": 64,
"minLength": 1,
"pattern": "^-?[0-9]+(\\.[0-9]+)?$"
},
"since": {
"type": "string",
"format": "date-time"
}
},
"x-stainless-model": "kraken_embed.kraken_embed_current_day_pnl"
}Fields
pnl: KrakenEmbedCurrentDayPnlPnlsince: DateTime<Utc>Trait Implementations
Sourceimpl Clone for KrakenEmbedCurrentDayPnl
impl Clone for KrakenEmbedCurrentDayPnl
Sourcefn clone(&self) -> KrakenEmbedCurrentDayPnl
fn clone(&self) -> KrakenEmbedCurrentDayPnl
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KrakenEmbedCurrentDayPnl
impl Debug for KrakenEmbedCurrentDayPnl
Sourceimpl<'de> Deserialize<'de> for KrakenEmbedCurrentDayPnl
impl<'de> Deserialize<'de> for KrakenEmbedCurrentDayPnl
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&KrakenEmbedCurrentDayPnl> for KrakenEmbedCurrentDayPnl
impl From<&KrakenEmbedCurrentDayPnl> for KrakenEmbedCurrentDayPnl
Sourcefn from(value: &KrakenEmbedCurrentDayPnl) -> Self
fn from(value: &KrakenEmbedCurrentDayPnl) -> Self
Converts to this type from the input type.
Sourceimpl From<KrakenEmbedCurrentDayPnl> for KrakenEmbedGetPortfolioSummaryResponseDataResultCurrentDayPnl
impl From<KrakenEmbedCurrentDayPnl> for KrakenEmbedGetPortfolioSummaryResponseDataResultCurrentDayPnl
Sourcefn from(value: KrakenEmbedCurrentDayPnl) -> Self
fn from(value: KrakenEmbedCurrentDayPnl) -> Self
Converts to this type from the input type.