pub struct KrakenEmbedCustomOrderCancelledWebhookPayload {
pub cancelled_at: String,
pub custom_order_id: String,
pub reason: String,
pub type_: KrakenEmbedCustomOrderCancelledWebhookPayloadType,
pub user_id: String,
}Expand description
Payload for the kraken_embed.custom_order.cancelled webhook event.
JSON schema
{
"title": "KrakenEmbedCustomOrderCancelledWebhookPayload",
"description": "Payload for the kraken_embed.custom_order.cancelled
webhook event.",
"type": "object",
"required": [
"cancelled_at",
"custom_order_id",
"reason",
"type",
"user_id"
],
"properties": {
"cancelled_at": {
"description": "ISO 8601 timestamp of when the custom order was
cancelled.",
"type": "string"
},
"custom_order_id": {
"description": "The ID of the cancelled custom order.",
"type": "string"
},
"reason": {
"description": "A human-readable description of why the custom order was cancelled. Intended for display and logging purposes only.",
"type": "string"
},
"type": {
"description": "The type of webhook event.",
"type": "string",
"enum": [
"kraken_embed.custom_order.cancelled"
]
},
"user_id": {
"description": "The ID of the user.",
"type": "string"
}
},
"x-stainless-model":
"webhooks.kraken_embed_custom_order_cancelled_webhook_payload"
}Fields
cancelled_at: StringISO 8601 timestamp of when the custom order was cancelled.
custom_order_id: StringThe ID of the cancelled custom order.
reason: StringA human-readable description of why the custom order was cancelled. Intended for display and logging purposes only.
type_: KrakenEmbedCustomOrderCancelledWebhookPayloadTypeThe type of webhook event.
user_id: StringThe ID of the user.