pub struct KrakenEmbedCustomOrderExecutionFailedWebhookPayload {
pub custom_order_id: String,
pub failed_at: String,
pub reason: String,
pub type_: KrakenEmbedCustomOrderExecutionFailedWebhookPayloadType,
pub user_id: String,
}Expand description
Payload for the kraken_embed.custom_order.execution_failed webhook event.
JSON schema
{
"title": "KrakenEmbedCustomOrderExecutionFailedWebhookPayload",
"description": "Payload for the
kraken_embed.custom_order.execution_failed webhook event.",
"type": "object",
"required": [
"custom_order_id",
"failed_at",
"reason",
"type",
"user_id"
],
"properties": {
"custom_order_id": {
"description": "The ID of the custom order that failed to
execute.",
"type": "string"
},
"failed_at": {
"description": "ISO 8601 timestamp of when the custom order
execution failed.",
"type": "string"
},
"reason": {
"description": "A human-readable description of why the custom
order execution failed. Intended for display and logging purposes
only.",
"type": "string"
},
"type": {
"description": "The type of webhook event.",
"type": "string",
"enum": [
"kraken_embed.custom_order.execution_failed"
]
},
"user_id": {
"description": "The ID of the user.",
"type": "string"
}
},
"x-stainless-model":
"webhooks.kraken_embed_custom_order_execution_failed_webhook_payload"
}Fields
custom_order_id: StringThe ID of the custom order that failed to execute.
failed_at: StringISO 8601 timestamp of when the custom order execution failed.
reason: StringA human-readable description of why the custom order execution failed. Intended for display and logging purposes only.
type_: KrakenEmbedCustomOrderExecutionFailedWebhookPayloadTypeThe type of webhook event.
user_id: StringThe ID of the user.