pub struct KrakenEmbedEarnAprEstimate {
pub high: KrakenEmbedEarnAprEstimateHigh,
pub low: KrakenEmbedEarnAprEstimateLow,
}Expand description
Low and high estimate of the yield of an earn asset.
JSON schema
{
"title": "KrakenEmbedEarnAprEstimate",
"description": "Low and high estimate of the yield of an earn asset.",
"type": "object",
"required": [
"high",
"low"
],
"properties": {
"high": {
"type": "string",
"maxLength": 64,
"minLength": 1,
"pattern": "^-?[0-9]+(\\.[0-9]+)?$"
},
"low": {
"type": "string",
"maxLength": 64,
"minLength": 1,
"pattern": "^-?[0-9]+(\\.[0-9]+)?$"
}
},
"x-stainless-model": "kraken_embed.kraken_embed_earn_apr_estimate"
}Fields
high: KrakenEmbedEarnAprEstimateHighlow: KrakenEmbedEarnAprEstimateLowTrait Implementations
Sourceimpl Clone for KrakenEmbedEarnAprEstimate
impl Clone for KrakenEmbedEarnAprEstimate
Sourcefn clone(&self) -> KrakenEmbedEarnAprEstimate
fn clone(&self) -> KrakenEmbedEarnAprEstimate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KrakenEmbedEarnAprEstimate
impl Debug for KrakenEmbedEarnAprEstimate
Sourceimpl<'de> Deserialize<'de> for KrakenEmbedEarnAprEstimate
impl<'de> Deserialize<'de> for KrakenEmbedEarnAprEstimate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&KrakenEmbedEarnAprEstimate> for KrakenEmbedEarnAprEstimate
impl From<&KrakenEmbedEarnAprEstimate> for KrakenEmbedEarnAprEstimate
Sourcefn from(value: &KrakenEmbedEarnAprEstimate) -> Self
fn from(value: &KrakenEmbedEarnAprEstimate) -> Self
Converts to this type from the input type.