pub struct LinkedAccountBaseWallet {
pub address: String,
pub chain_type: LinkedAccountBaseWalletChainType,
pub type_: LinkedAccountBaseWalletType,
}Expand description
Base schema for wallet accounts linked to the user.
JSON schema
{
"title": "LinkedAccountBaseWallet",
"description": "Base schema for wallet accounts linked to the user.",
"type": "object",
"required": [
"address",
"chain_type",
"type"
],
"properties": {
"address": {
"type": "string"
},
"chain_type": {
"type": "string",
"enum": [
"ethereum",
"solana"
]
},
"type": {
"type": "string",
"enum": [
"smart_wallet",
"wallet"
]
}
},
"x-stainless-model": "users.linked_account_base_wallet"
}Fields
address: Stringchain_type: LinkedAccountBaseWalletChainTypetype_: LinkedAccountBaseWalletTypeTrait Implementations
Sourceimpl Clone for LinkedAccountBaseWallet
impl Clone for LinkedAccountBaseWallet
Sourcefn clone(&self) -> LinkedAccountBaseWallet
fn clone(&self) -> LinkedAccountBaseWallet
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LinkedAccountBaseWallet
impl Debug for LinkedAccountBaseWallet
Sourceimpl<'de> Deserialize<'de> for LinkedAccountBaseWallet
impl<'de> Deserialize<'de> for LinkedAccountBaseWallet
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&LinkedAccountBaseWallet> for LinkedAccountBaseWallet
impl From<&LinkedAccountBaseWallet> for LinkedAccountBaseWallet
Sourcefn from(value: &LinkedAccountBaseWallet) -> Self
fn from(value: &LinkedAccountBaseWallet) -> Self
Converts to this type from the input type.