pub struct NamedTokenTransferSource {
pub amount: NamedTokenTransferSourceAmount,
pub asset: String,
pub chain: String,
}Expand description
Source for a transfer identified by a named asset (e.g. “usdc”, “eth”). Use this variant for first-class assets maintained by Privy.
JSON schema
{
"title": "NamedTokenTransferSource",
"description": "Source for a transfer identified by a named asset (e.g.
\"usdc\", \"eth\"). Use this variant for first-class assets maintained
by Privy.",
"examples": [
{
"amount": "10.5",
"asset": "usdc",
"chain": "base"
}
],
"type": "object",
"required": [
"amount",
"asset",
"chain"
],
"properties": {
"amount": {
"description": "Amount as a decimal string in the token's standard unit (e.g. \"1.5\" for 1.5 USDC, \"0.01\" for 0.01 ETH). Not in the smallest on-chain unit (wei, lamports, etc.). Maximum 100 characters.",
"type": "string",
"maxLength": 100
},
"asset": {
"description": "The asset to transfer. Supported: 'usdc', 'usdb', 'usdt' (stablecoins), 'eth' (native Ethereum), 'sol' (native Solana).",
"type": "string"
},
"chain": {
"description": "The blockchain network on which to perform the
transfer. Supported chains include: 'ethereum', 'base', 'arbitrum',
'polygon', 'solana', and their respective testnets.",
"type": "string"
}
},
"x-stainless-model": "wallets.named_token_transfer_source"
}Fields
amount: NamedTokenTransferSourceAmountAmount as a decimal string in the token’s standard unit (e.g. “1.5” for 1.5 USDC, “0.01” for 0.01 ETH). Not in the smallest on-chain unit (wei, lamports, etc.). Maximum 100 characters.
asset: StringThe asset to transfer. Supported: ‘usdc’, ‘usdb’, ‘usdt’ (stablecoins), ‘eth’ (native Ethereum), ‘sol’ (native Solana).
chain: StringThe blockchain network on which to perform the transfer. Supported chains include: ‘ethereum’, ‘base’, ‘arbitrum’, ‘polygon’, ‘solana’, and their respective testnets.