pub struct OAuthLinkResponseBody {
pub created_at: f64,
pub custom_metadata: Option<CustomMetadata>,
pub has_accepted_terms: bool,
pub id: String,
pub is_guest: bool,
pub linked_accounts: Vec<LinkedAccount>,
pub mfa_methods: Vec<LinkedMfaMethod>,
pub oauth_tokens: Option<OAuthTokens>,
}Expand description
The response for linking an OAuth account.
JSON schema
{
"title": "OAuthLinkResponseBody",
"description": "The response for linking an OAuth account.",
"allOf": [
{
"$ref": "#/components/schemas/User"
},
{
"type": "object",
"properties": {
"oauth_tokens": {
"$ref": "#/components/schemas/OAuthTokens"
}
}
}
],
"x-stainless-model": "client_auth.oauth_link_response_body"
}Fields
created_at: f64custom_metadata: Option<CustomMetadata>has_accepted_terms: boolIndicates if the user has accepted the terms of service.
id: Stringis_guest: boolIndicates if the user is a guest account user.
linked_accounts: Vec<LinkedAccount>mfa_methods: Vec<LinkedMfaMethod>oauth_tokens: Option<OAuthTokens>Trait Implementations
Sourceimpl Clone for OAuthLinkResponseBody
impl Clone for OAuthLinkResponseBody
Sourcefn clone(&self) -> OAuthLinkResponseBody
fn clone(&self) -> OAuthLinkResponseBody
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OAuthLinkResponseBody
impl Debug for OAuthLinkResponseBody
Sourceimpl<'de> Deserialize<'de> for OAuthLinkResponseBody
impl<'de> Deserialize<'de> for OAuthLinkResponseBody
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&OAuthLinkResponseBody> for OAuthLinkResponseBody
impl From<&OAuthLinkResponseBody> for OAuthLinkResponseBody
Sourcefn from(value: &OAuthLinkResponseBody) -> Self
fn from(value: &OAuthLinkResponseBody) -> Self
Converts to this type from the input type.