pub struct OAuthTokenDeviceCodePendingError {
pub error: OAuthTokenDeviceCodePendingErrorError,
pub error_description: Option<String>,
pub interval: Option<f64>,
}Expand description
Error response returned while the device authorization is still pending (RFC 8628 Section 3.5).
JSON schema
{
"title": "OAuthTokenDeviceCodePendingError",
"description": "Error response returned while the device authorization
is still pending (RFC 8628 Section 3.5).",
"type": "object",
"required": [
"error"
],
"properties": {
"error": {
"description": "The error code indicating why the token request
failed.",
"type": "string",
"enum": [
"access_denied",
"authorization_pending",
"expired_token",
"slow_down"
]
},
"error_description": {
"description": "Human-readable description of the error.",
"type": "string"
},
"interval": {
"description": "The minimum polling interval in seconds.",
"type": "number"
}
},
"x-stainless-model":
"client_auth.oauth_token_device_code_pending_error"
}Fields
error: OAuthTokenDeviceCodePendingErrorErrorThe error code indicating why the token request failed.
error_description: Option<String>Human-readable description of the error.
interval: Option<f64>Trait Implementations
Sourceimpl Clone for OAuthTokenDeviceCodePendingError
impl Clone for OAuthTokenDeviceCodePendingError
Sourcefn clone(&self) -> OAuthTokenDeviceCodePendingError
fn clone(&self) -> OAuthTokenDeviceCodePendingError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for OAuthTokenDeviceCodePendingError
impl<'de> Deserialize<'de> for OAuthTokenDeviceCodePendingError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&OAuthTokenDeviceCodePendingError> for OAuthTokenDeviceCodePendingError
impl From<&OAuthTokenDeviceCodePendingError> for OAuthTokenDeviceCodePendingError
Sourcefn from(value: &OAuthTokenDeviceCodePendingError) -> Self
fn from(value: &OAuthTokenDeviceCodePendingError) -> Self
Converts to this type from the input type.