pub struct OptionalRefreshTokenInput {
pub refresh_token: Option<String>,
}Expand description
The input for refreshing a session or logging out.
JSON schema
{
"title": "OptionalRefreshTokenInput",
"description": "The input for refreshing a session or logging out.",
"type": "object",
"properties": {
"refresh_token": {
"type": "string"
}
}
}Fields
refresh_token: Option<String>Trait Implementations
Sourceimpl Clone for OptionalRefreshTokenInput
impl Clone for OptionalRefreshTokenInput
Sourcefn clone(&self) -> OptionalRefreshTokenInput
fn clone(&self) -> OptionalRefreshTokenInput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OptionalRefreshTokenInput
impl Debug for OptionalRefreshTokenInput
Sourceimpl Default for OptionalRefreshTokenInput
impl Default for OptionalRefreshTokenInput
Sourceimpl<'de> Deserialize<'de> for OptionalRefreshTokenInput
impl<'de> Deserialize<'de> for OptionalRefreshTokenInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&OptionalRefreshTokenInput> for OptionalRefreshTokenInput
impl From<&OptionalRefreshTokenInput> for OptionalRefreshTokenInput
Sourcefn from(value: &OptionalRefreshTokenInput) -> Self
fn from(value: &OptionalRefreshTokenInput) -> Self
Converts to this type from the input type.