pub struct PatchUsersCustomMetadata {
pub custom_metadata: CustomMetadata,
}Expand description
The payload for partially updating custom metadata on a user.
JSON schema
{
"title": "PatchUsersCustomMetadata",
"description": "The payload for partially updating custom metadata on a
user.",
"type": "object",
"required": [
"custom_metadata"
],
"properties": {
"custom_metadata": {
"$ref": "#/components/schemas/CustomMetadata"
}
},
"x-stainless-model": "users.patch_users_custom_metadata"
}Fields
custom_metadata: CustomMetadataTrait Implementations
Sourceimpl Clone for PatchUsersCustomMetadata
impl Clone for PatchUsersCustomMetadata
Sourcefn clone(&self) -> PatchUsersCustomMetadata
fn clone(&self) -> PatchUsersCustomMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PatchUsersCustomMetadata
impl Debug for PatchUsersCustomMetadata
Sourceimpl<'de> Deserialize<'de> for PatchUsersCustomMetadata
impl<'de> Deserialize<'de> for PatchUsersCustomMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&PatchUsersCustomMetadata> for PatchUsersCustomMetadata
impl From<&PatchUsersCustomMetadata> for PatchUsersCustomMetadata
Sourcefn from(value: &PatchUsersCustomMetadata) -> Self
fn from(value: &PatchUsersCustomMetadata) -> Self
Converts to this type from the input type.