pub struct PolicyIntentResponseActionResult {
pub authorized_by_display_name: Option<String>,
pub authorized_by_id: Option<String>,
pub executed_at: f64,
pub prior_state: PolicyIntentResponseActionResultPriorState,
pub response_body: PolicyIntentResponseActionResultResponseBody,
pub status_code: f64,
}Expand description
Result of policy update execution (only present if status is ‘executed’ or ‘failed’)
JSON schema
{
"description": "Result of policy update execution (only present if
status is 'executed' or 'failed')",
"type": "object",
"required": [
"executed_at",
"prior_state",
"response_body",
"status_code"
],
"properties": {
"authorized_by_display_name": {
"description": "Display name of the key quorum that authorized
execution",
"type": "string"
},
"authorized_by_id": {
"description": "ID of the key quorum that authorized execution",
"type": "string"
},
"executed_at": {
"description": "Unix timestamp when the action was executed",
"type": "number"
},
"prior_state": {
"description": "State of the policy immediately before execution",
"type": "object",
"required": [
"chain_type",
"created_at",
"id",
"name",
"owner_id",
"rules",
"version"
],
"properties": {
"chain_type": {
"$ref": "#/components/schemas/PolicyChainType"
},
"created_at": {
"description": "Unix timestamp of when the policy was created
in milliseconds.",
"type": "number"
},
"id": {
"description": "Unique ID of the created policy. This will be
the primary identifier when using the policy in the future.",
"type": "string",
"maxLength": 24,
"minLength": 24
},
"name": {
"description": "Name to assign to policy.",
"type": "string",
"maxLength": 50,
"minLength": 1
},
"owner_id": {
"description": "The key quorum ID of the owner of the policy.",
"type": [
"string",
"null"
]
},
"rules": {
"type": "array",
"items": {
"$ref": "#/components/schemas/PolicyRuleResponse"
}
},
"version": {
"description": "Version of the policy. Currently, 1.0 is the
only version.",
"type": "string",
"enum": [
"1.0"
]
}
}
},
"response_body": {
"type": "object",
"required": [
"chain_type",
"created_at",
"id",
"name",
"owner_id",
"rules",
"version"
],
"properties": {
"chain_type": {
"$ref": "#/components/schemas/PolicyChainType"
},
"created_at": {
"description": "Unix timestamp of when the policy was created
in milliseconds.",
"type": "number"
},
"id": {
"description": "Unique ID of the created policy. This will be
the primary identifier when using the policy in the future.",
"type": "string",
"maxLength": 24,
"minLength": 24
},
"name": {
"description": "Name to assign to policy.",
"type": "string",
"maxLength": 50,
"minLength": 1
},
"owner_id": {
"description": "The key quorum ID of the owner of the policy.",
"type": [
"string",
"null"
]
},
"rules": {
"type": "array",
"items": {
"$ref": "#/components/schemas/PolicyRuleResponse"
}
},
"version": {
"description": "Version of the policy. Currently, 1.0 is the
only version.",
"type": "string",
"enum": [
"1.0"
]
}
}
},
"status_code": {
"description": "HTTP status code from the action execution",
"type": "number"
}
}
}Fields
Display name of the key quorum that authorized execution
ID of the key quorum that authorized execution
executed_at: f64prior_state: PolicyIntentResponseActionResultPriorStateresponse_body: PolicyIntentResponseActionResultResponseBodystatus_code: f64Trait Implementations
Sourceimpl Clone for PolicyIntentResponseActionResult
impl Clone for PolicyIntentResponseActionResult
Sourcefn clone(&self) -> PolicyIntentResponseActionResult
fn clone(&self) -> PolicyIntentResponseActionResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PolicyIntentResponseActionResult
impl<'de> Deserialize<'de> for PolicyIntentResponseActionResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&PolicyIntentResponseActionResult> for PolicyIntentResponseActionResult
impl From<&PolicyIntentResponseActionResult> for PolicyIntentResponseActionResult
Sourcefn from(value: &PolicyIntentResponseActionResult) -> Self
fn from(value: &PolicyIntentResponseActionResult) -> Self
Converts to this type from the input type.