pub struct PolicyIntentResponseActionResultPriorState {
pub chain_type: PolicyChainType,
pub created_at: f64,
pub id: PolicyIntentResponseActionResultPriorStateId,
pub name: PolicyIntentResponseActionResultPriorStateName,
pub owner_id: Option<String>,
pub rules: Vec<PolicyRuleResponse>,
pub version: PolicyIntentResponseActionResultPriorStateVersion,
}Expand description
State of the policy immediately before execution
JSON schema
{
"description": "State of the policy immediately before execution",
"type": "object",
"required": [
"chain_type",
"created_at",
"id",
"name",
"owner_id",
"rules",
"version"
],
"properties": {
"chain_type": {
"$ref": "#/components/schemas/PolicyChainType"
},
"created_at": {
"description": "Unix timestamp of when the policy was created in
milliseconds.",
"type": "number"
},
"id": {
"description": "Unique ID of the created policy. This will be the
primary identifier when using the policy in the future.",
"type": "string",
"maxLength": 24,
"minLength": 24
},
"name": {
"description": "Name to assign to policy.",
"type": "string",
"maxLength": 50,
"minLength": 1
},
"owner_id": {
"description": "The key quorum ID of the owner of the policy.",
"type": [
"string",
"null"
]
},
"rules": {
"type": "array",
"items": {
"$ref": "#/components/schemas/PolicyRuleResponse"
}
},
"version": {
"description": "Version of the policy. Currently, 1.0 is the only
version.",
"type": "string",
"enum": [
"1.0"
]
}
}
}Fields
chain_type: PolicyChainTypecreated_at: f64id: PolicyIntentResponseActionResultPriorStateIdUnique ID of the created policy. This will be the primary identifier when using the policy in the future.
name: PolicyIntentResponseActionResultPriorStateNameName to assign to policy.
owner_id: Option<String>The key quorum ID of the owner of the policy.
rules: Vec<PolicyRuleResponse>version: PolicyIntentResponseActionResultPriorStateVersionVersion of the policy. Currently, 1.0 is the only version.