pub struct PolicyIntentResponseRequestDetails {
pub body: PolicyIntentResponseRequestDetailsBody,
pub method: PolicyIntentResponseRequestDetailsMethod,
pub url: String,
}Expand description
The original policy update request that would be sent to the policy endpoint
JSON schema
{
"description": "The original policy update request that would be sent
to the policy endpoint",
"type": "object",
"required": [
"body",
"method",
"url"
],
"properties": {
"body": {
"type": "object",
"properties": {
"name": {
"description": "Name to assign to policy.",
"type": "string",
"maxLength": 50,
"minLength": 1
},
"owner": {
"$ref": "#/components/schemas/OwnerInput"
},
"owner_id": {
"allOf": [
{
"$ref": "#/components/schemas/OwnerIdInput"
},
{}
]
},
"rules": {
"type": "array",
"items": {
"$ref": "#/components/schemas/PolicyRuleRequestBody"
}
}
}
},
"method": {
"type": "string",
"enum": [
"PATCH"
]
},
"url": {
"type": "string"
}
}
}Fields
body: PolicyIntentResponseRequestDetailsBodymethod: PolicyIntentResponseRequestDetailsMethodurl: StringTrait Implementations
Sourceimpl Clone for PolicyIntentResponseRequestDetails
impl Clone for PolicyIntentResponseRequestDetails
Sourcefn clone(&self) -> PolicyIntentResponseRequestDetails
fn clone(&self) -> PolicyIntentResponseRequestDetails
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for PolicyIntentResponseRequestDetails
impl<'de> Deserialize<'de> for PolicyIntentResponseRequestDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&PolicyIntentResponseRequestDetails> for PolicyIntentResponseRequestDetails
impl From<&PolicyIntentResponseRequestDetails> for PolicyIntentResponseRequestDetails
Sourcefn from(value: &PolicyIntentResponseRequestDetails) -> Self
fn from(value: &PolicyIntentResponseRequestDetails) -> Self
Converts to this type from the input type.