pub struct PolicyRuleRequestParams {
pub policy_id: PolicyRuleRequestParamsPolicyId,
pub rule_id: PolicyRuleRequestParamsRuleId,
}Expand description
Unique IDs of the policy and the rule within the policy to take actions on.
JSON schema
{
"description": "Unique IDs of the policy and the rule within the policy to take actions on.",
"type": "object",
"required": [
"policy_id",
"rule_id"
],
"properties": {
"policy_id": {
"type": "string",
"maxLength": 24,
"minLength": 24
},
"rule_id": {
"type": "string",
"maxLength": 24,
"minLength": 24
}
}
}Fields
policy_id: PolicyRuleRequestParamsPolicyIdrule_id: PolicyRuleRequestParamsRuleIdTrait Implementations
Sourceimpl Clone for PolicyRuleRequestParams
impl Clone for PolicyRuleRequestParams
Sourcefn clone(&self) -> PolicyRuleRequestParams
fn clone(&self) -> PolicyRuleRequestParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PolicyRuleRequestParams
impl Debug for PolicyRuleRequestParams
Sourceimpl<'de> Deserialize<'de> for PolicyRuleRequestParams
impl<'de> Deserialize<'de> for PolicyRuleRequestParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&PolicyRuleRequestParams> for PolicyRuleRequestParams
impl From<&PolicyRuleRequestParams> for PolicyRuleRequestParams
Sourcefn from(value: &PolicyRuleRequestParams) -> Self
fn from(value: &PolicyRuleRequestParams) -> Self
Converts to this type from the input type.