RpcIntentResponse

Struct RpcIntentResponse 

pub struct RpcIntentResponse {
Show 16 fields pub action_result: Option<BaseActionResult>, pub authorization_details: Vec<IntentAuthorization>, pub created_at: f64, pub created_by_display_name: String, pub created_by_id: Option<String>, pub current_resource_data: Option<Wallet>, pub custom_expiry: bool, pub dismissal_reason: Option<String>, pub dismissed_at: Option<f64>, pub expires_at: f64, pub intent_id: String, pub intent_type: RpcIntentResponseIntentType, pub rejected_at: Option<f64>, pub request_details: RpcIntentResponseRequestDetails, pub resource_id: String, pub status: IntentStatus,
}
Response for an RPC intent

JSON schema
{
 "title": "RpcIntentResponse",
 "description": "Response for an RPC intent",
 "examples": [
   {
     "authorization_details": [
       {
         "display_name": "Admin Key Quorum",
         "members": [
           {
             "signed_at": null,
             "type": "user",
             "user_id": "did:privy:clabcd123"
           }
         ],
         "threshold": 1
       }
     ],
     "created_at": 1741834854578,
     "created_by_display_name": "developer@example.com",
     "created_by_id": "did:privy:clabcd123",
     "custom_expiry": false,
     "expires_at": 1741921254578,
     "intent_id": "clpq1234567890abcdefghij",
     "intent_type": "RPC",
     "request_details": {
       "body": {
         "caip2": "eip155:8453",
         "chain_type": "ethereum",
         "method": "eth_sendTransaction",
         "params": {
           "transaction": {
             "to": "0x0000000000000000000000000000000000000000",
             "value": 1
           }
         }
       },
       "method": "POST",
       "url": "https://api.privy.io/v1/wallets/xs76o3pi0v5syd62ui1wmijw/rpc"
     },
     "resource_id": "xs76o3pi0v5syd62ui1wmijw",
     "status": "pending"
   }
 ],
 "allOf": [
   {
     "$ref": "#/components/schemas/BaseIntentResponse"
   },
   {
     "type": "object",
     "required": [
       "intent_type",
       "request_details"
     ],
     "properties": {
       "action_result": {
         "title": "BaseActionResult",
         "description": "Result of RPC execution (only present if status
is 'executed' or 'failed')",
         "allOf": [
           {
             "$ref": "#/components/schemas/BaseActionResult"
           },
           {
             "type": "object",
             "required": [
               "response_body"
             ],
             "properties": {
               "response_body": {
                 "$ref": "#/components/schemas/WalletRpcResponse"
               }
             }
           }
         ],
         "x-stainless-model": "intents.base_action_result"
       },
       "current_resource_data": {
         "allOf": [
           {
             "$ref": "#/components/schemas/Wallet"
           },
           {
             "description": "Current state of the wallet before any changes. If undefined, the resource was deleted and no longer exists"
           }
         ]
       },
       "intent_type": {
         "type": "string",
         "enum": [
           "RPC"
         ]
       },
       "request_details": {
         "description": "The original RPC request that would be sent to
the wallet endpoint",
         "type": "object",
         "required": [
           "body",
           "method",
           "url"
         ],
         "properties": {
           "body": {
             "$ref": "#/components/schemas/WalletRpcRequestBody"
           },
           "method": {
             "type": "string",
             "enum": [
               "POST"
             ]
           },
           "url": {
             "type": "string"
           }
         }
       }
     }
   }
 ],
 "x-stainless-model": "intents.rpc_intent_response"
}

Fields

action_result: Option<BaseActionResult>authorization_details: Vec<IntentAuthorization>

Detailed authorization information including key quorum members, thresholds, and signature status

created_at: f64created_by_display_name: String

Display name of the user who created the intent

created_by_id: Option<String>

ID of the user who created the intent. If undefined, the intent was created using the app secret

current_resource_data: Option<Wallet>custom_expiry: bool

Whether this intent has a custom expiry time set by the client. If false, the intent expires after a default duration.

dismissal_reason: Option<String>

Human-readable reason for dismissal, present when status is ‘dismissed’

dismissed_at: Option<f64>expires_at: f64intent_id: String

Unique ID for the intent

intent_type: RpcIntentResponseIntentTyperejected_at: Option<f64>request_details: RpcIntentResponseRequestDetailsresource_id: String

ID of the resource being modified (wallet_id, policy_id, etc)

status: IntentStatus