pub struct RuleIntentResponse {Show 17 fields
pub action_result: Option<BaseActionResult>,
pub authorization_details: Vec<IntentAuthorization>,
pub created_at: f64,
pub created_by_display_name: String,
pub created_by_id: Option<String>,
pub current_resource_data: Option<PolicyRuleResponse>,
pub custom_expiry: bool,
pub dismissal_reason: Option<String>,
pub dismissed_at: Option<f64>,
pub expires_at: f64,
pub intent_id: String,
pub intent_type: RuleIntentResponseIntentType,
pub policy: Option<Policy>,
pub rejected_at: Option<f64>,
pub request_details: RuleIntentRequestDetails,
pub resource_id: String,
pub status: IntentStatus,
}Expand description
Response for a rule intent
JSON schema
{
"title": "RuleIntentResponse",
"description": "Response for a rule intent",
"allOf": [
{
"$ref": "#/components/schemas/BaseIntentResponse"
},
{
"type": "object",
"required": [
"intent_type",
"request_details"
],
"properties": {
"action_result": {
"title": "BaseActionResult",
"description": "Result of rule execution (only present if
status is 'executed' or 'failed')",
"allOf": [
{
"$ref": "#/components/schemas/BaseActionResult"
},
{
"type": "object",
"properties": {
"prior_state": {
"allOf": [
{
"$ref": "#/components/schemas/PolicyRuleResponse"
},
{
"description": "State of the rule immediately
before execution. Undefined for create intents"
}
]
},
"response_body": {
"oneOf": [
{
"$ref": "#/components/schemas/PolicyRuleResponse"
},
{
"$ref": "#/components/schemas/SuccessResponse"
}
]
}
}
}
],
"x-stainless-model": "intents.base_action_result"
},
"current_resource_data": {
"allOf": [
{
"$ref": "#/components/schemas/PolicyRuleResponse"
},
{
"description": "Current state of the rule before any
changes. Undefined for create intents or if the rule was deleted"
}
]
},
"intent_type": {
"type": "string",
"enum": [
"RULE"
]
},
"policy": {
"allOf": [
{
"$ref": "#/components/schemas/Policy"
},
{
"description": "Parent policy containing this rule,
including sibling rules for contextual display"
}
]
},
"request_details": {
"$ref": "#/components/schemas/RuleIntentRequestDetails"
}
}
}
],
"x-stainless-model": "intents.rule_intent_response"
}Fields
action_result: Option<BaseActionResult>Detailed authorization information including key quorum members, thresholds, and signature status
created_at: f64created_by_display_name: StringDisplay name of the user who created the intent
created_by_id: Option<String>ID of the user who created the intent. If undefined, the intent was created using the app secret
current_resource_data: Option<PolicyRuleResponse>custom_expiry: boolWhether this intent has a custom expiry time set by the client. If false, the intent expires after a default duration.
dismissal_reason: Option<String>Human-readable reason for dismissal, present when status is ‘dismissed’
dismissed_at: Option<f64>expires_at: f64intent_id: StringUnique ID for the intent
intent_type: RuleIntentResponseIntentTypepolicy: Option<Policy>rejected_at: Option<f64>request_details: RuleIntentRequestDetailsresource_id: StringID of the resource being modified (wallet_id, policy_id, etc)
status: IntentStatusTrait Implementations
Sourceimpl Clone for RuleIntentResponse
impl Clone for RuleIntentResponse
Sourcefn clone(&self) -> RuleIntentResponse
fn clone(&self) -> RuleIntentResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RuleIntentResponse
impl Debug for RuleIntentResponse
Sourceimpl<'de> Deserialize<'de> for RuleIntentResponse
impl<'de> Deserialize<'de> for RuleIntentResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&RuleIntentResponse> for RuleIntentResponse
impl From<&RuleIntentResponse> for RuleIntentResponse
Sourcefn from(value: &RuleIntentResponse) -> Self
fn from(value: &RuleIntentResponse) -> Self
Converts to this type from the input type.
Sourceimpl From<RuleIntentResponse> for IntentResponse
impl From<RuleIntentResponse> for IntentResponse
Sourcefn from(value: RuleIntentResponse) -> Self
fn from(value: RuleIntentResponse) -> Self
Converts to this type from the input type.