pub struct SeedPhraseExportWebhookPayload {
pub export_source: Option<SeedPhraseExportWebhookPayloadExportSource>,
pub type_: SeedPhraseExportWebhookPayloadType,
pub user_id: String,
pub wallet_address: String,
pub wallet_id: String,
}Expand description
Payload for the wallet.seed_phrase_export webhook event.
JSON schema
{
"title": "SeedPhraseExportWebhookPayload",
"description": "Payload for the wallet.seed_phrase_export webhook
event.",
"type": "object",
"required": [
"type",
"user_id",
"wallet_address",
"wallet_id"
],
"properties": {
"export_source": {
"type": "string",
"enum": [
"client",
"display"
]
},
"type": {
"description": "The type of webhook event.",
"type": "string",
"enum": [
"wallet.seed_phrase_export"
]
},
"user_id": {
"description": "The ID of the user who exported the seed phrase.",
"type": "string"
},
"wallet_address": {
"description": "The address of the wallet.",
"type": "string"
},
"wallet_id": {
"description": "The ID of the wallet.",
"type": "string"
}
},
"x-stainless-model": "webhooks.seed_phrase_export_webhook_payload"
}Fields
export_source: Option<SeedPhraseExportWebhookPayloadExportSource>type_: SeedPhraseExportWebhookPayloadTypeThe type of webhook event.
user_id: StringThe ID of the user who exported the seed phrase.
wallet_address: StringThe address of the wallet.
wallet_id: StringThe ID of the wallet.