pub struct SparkGetStaticDepositAddressRpcInput {
pub method: SparkGetStaticDepositAddressRpcInputMethod,
pub network: Option<SparkNetwork>,
}Expand description
Gets a static deposit address for the Spark wallet.
JSON schema
{
"title": "SparkGetStaticDepositAddressRpcInput",
"description": "Gets a static deposit address for the Spark wallet.",
"type": "object",
"required": [
"method"
],
"properties": {
"method": {
"type": "string",
"enum": [
"getStaticDepositAddress"
]
},
"network": {
"allOf": [
{
"$ref": "#/components/schemas/SparkNetwork"
},
{
"default": "MAINNET"
}
]
}
},
"x-stainless-model":
"wallets.spark_get_static_deposit_address_rpc_input"
}Fields
method: SparkGetStaticDepositAddressRpcInputMethodnetwork: Option<SparkNetwork>Trait Implementations
Sourceimpl Clone for SparkGetStaticDepositAddressRpcInput
impl Clone for SparkGetStaticDepositAddressRpcInput
Sourcefn clone(&self) -> SparkGetStaticDepositAddressRpcInput
fn clone(&self) -> SparkGetStaticDepositAddressRpcInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SparkGetStaticDepositAddressRpcInput
impl<'de> Deserialize<'de> for SparkGetStaticDepositAddressRpcInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&SparkGetStaticDepositAddressRpcInput> for SparkGetStaticDepositAddressRpcInput
impl From<&SparkGetStaticDepositAddressRpcInput> for SparkGetStaticDepositAddressRpcInput
Sourcefn from(value: &SparkGetStaticDepositAddressRpcInput) -> Self
fn from(value: &SparkGetStaticDepositAddressRpcInput) -> Self
Converts to this type from the input type.
Sourceimpl From<SparkGetStaticDepositAddressRpcInput> for SparkRpcInput
impl From<SparkGetStaticDepositAddressRpcInput> for SparkRpcInput
Sourcefn from(value: SparkGetStaticDepositAddressRpcInput) -> Self
fn from(value: SparkGetStaticDepositAddressRpcInput) -> Self
Converts to this type from the input type.
Sourceimpl From<SparkGetStaticDepositAddressRpcInput> for WalletRpcRequestBody
impl From<SparkGetStaticDepositAddressRpcInput> for WalletRpcRequestBody
Sourcefn from(value: SparkGetStaticDepositAddressRpcInput) -> Self
fn from(value: SparkGetStaticDepositAddressRpcInput) -> Self
Converts to this type from the input type.