pub struct SwapSource {
pub asset_address: String,
pub caip2: String,
}Expand description
The input side of a swap request, including token and chain.
JSON schema
{
"title": "SwapSource",
"description": "The input side of a swap request, including token and
chain.",
"type": "object",
"required": [
"asset_address",
"caip2"
],
"properties": {
"asset_address": {
"description": "Token contract address to sell, or \"native\" for
the chain's native token.",
"type": "string"
},
"caip2": {
"description": "CAIP-2 chain identifier (e.g., \"eip155:1\").",
"type": "string"
}
},
"x-stainless-model": "swaps.swap_source"
}Fields
asset_address: StringToken contract address to sell, or “native” for the chain’s native token.
caip2: StringCAIP-2 chain identifier (e.g., “eip155:1”).