pub struct TelegramAuthResult {
pub auth_date: Option<f64>,
pub first_name: String,
pub hash: String,
pub id: Option<f64>,
pub last_name: Option<String>,
pub photo_url: Option<String>,
pub username: Option<String>,
}Expand description
Auth result object returned by Telegram when a user authenticates using the login widget.
JSON schema
{
"title": "TelegramAuthResult",
"description": "Auth result object returned by Telegram when a user
authenticates using the login widget.",
"type": "object",
"required": [
"first_name",
"hash"
],
"properties": {
"auth_date": {
"type": "number"
},
"first_name": {
"type": "string"
},
"hash": {
"type": "string"
},
"id": {
"type": "number"
},
"last_name": {
"type": "string"
},
"photo_url": {
"type": "string"
},
"username": {
"type": "string"
}
},
"x-stainless-model": "client_auth.telegram_auth_result"
}Fields
auth_date: Option<f64>first_name: Stringhash: Stringid: Option<f64>last_name: Option<String>photo_url: Option<String>username: Option<String>Trait Implementations
Sourceimpl Clone for TelegramAuthResult
impl Clone for TelegramAuthResult
Sourcefn clone(&self) -> TelegramAuthResult
fn clone(&self) -> TelegramAuthResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TelegramAuthResult
impl Debug for TelegramAuthResult
Sourceimpl<'de> Deserialize<'de> for TelegramAuthResult
impl<'de> Deserialize<'de> for TelegramAuthResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&TelegramAuthResult> for TelegramAuthResult
impl From<&TelegramAuthResult> for TelegramAuthResult
Sourcefn from(value: &TelegramAuthResult) -> Self
fn from(value: &TelegramAuthResult) -> Self
Converts to this type from the input type.