pub struct TelegramWebAppData {
pub auth_date: Option<f64>,
pub chat_instance: Option<String>,
pub chat_type: Option<String>,
pub hash: String,
pub query_id: Option<String>,
pub signature: Option<String>,
pub start_param: Option<String>,
pub user: String,
}Expand description
Auth result object returned by Telegram when a user authenticates using a mini app.
JSON schema
{
"title": "TelegramWebAppData",
"description": "Auth result object returned by Telegram when a user
authenticates using a mini app.",
"type": "object",
"required": [
"hash",
"user"
],
"properties": {
"auth_date": {
"type": "number"
},
"chat_instance": {
"type": "string"
},
"chat_type": {
"type": "string"
},
"hash": {
"type": "string"
},
"query_id": {
"type": "string"
},
"signature": {
"type": "string"
},
"start_param": {
"type": "string"
},
"user": {
"type": "string"
}
},
"x-stainless-model": "client_auth.telegram_web_app_data"
}Fields
auth_date: Option<f64>chat_instance: Option<String>chat_type: Option<String>hash: Stringquery_id: Option<String>signature: Option<String>start_param: Option<String>user: StringTrait Implementations
Sourceimpl Clone for TelegramWebAppData
impl Clone for TelegramWebAppData
Sourcefn clone(&self) -> TelegramWebAppData
fn clone(&self) -> TelegramWebAppData
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TelegramWebAppData
impl Debug for TelegramWebAppData
Sourceimpl<'de> Deserialize<'de> for TelegramWebAppData
impl<'de> Deserialize<'de> for TelegramWebAppData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&TelegramWebAppData> for TelegramWebAppData
impl From<&TelegramWebAppData> for TelegramWebAppData
Sourcefn from(value: &TelegramWebAppData) -> Self
fn from(value: &TelegramWebAppData) -> Self
Converts to this type from the input type.