pub struct TransactionScanningAssetValue {
pub usd_price: Option<String>,
pub value: Option<String>,
}Expand description
The value of an asset in a transaction scan result.
JSON schema
{
"title": "TransactionScanningAssetValue",
"description": "The value of an asset in a transaction scan result.",
"type": "object",
"properties": {
"usd_price": {
"type": "string"
},
"value": {
"type": "string"
}
},
"x-stainless-model": "transactions.transaction_scanning_asset_value"
}Fields
usd_price: Option<String>value: Option<String>Trait Implementations
Sourceimpl Clone for TransactionScanningAssetValue
impl Clone for TransactionScanningAssetValue
Sourcefn clone(&self) -> TransactionScanningAssetValue
fn clone(&self) -> TransactionScanningAssetValue
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TransactionScanningAssetValue
impl<'de> Deserialize<'de> for TransactionScanningAssetValue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&TransactionScanningAssetValue> for TransactionScanningAssetValue
impl From<&TransactionScanningAssetValue> for TransactionScanningAssetValue
Sourcefn from(value: &TransactionScanningAssetValue) -> Self
fn from(value: &TransactionScanningAssetValue) -> Self
Converts to this type from the input type.