pub struct TransferIntentResponse {Show 16 fields
pub action_result: Option<BaseActionResult>,
pub authorization_details: Vec<IntentAuthorization>,
pub created_at: f64,
pub created_by_display_name: String,
pub created_by_id: Option<String>,
pub current_resource_data: Option<Wallet>,
pub custom_expiry: bool,
pub dismissal_reason: Option<String>,
pub dismissed_at: Option<f64>,
pub expires_at: f64,
pub intent_id: String,
pub intent_type: TransferIntentResponseIntentType,
pub rejected_at: Option<f64>,
pub request_details: TransferIntentResponseRequestDetails,
pub resource_id: String,
pub status: IntentStatus,
}Expand description
Response for a transfer intent
JSON schema
{
"title": "TransferIntentResponse",
"description": "Response for a transfer intent",
"allOf": [
{
"$ref": "#/components/schemas/BaseIntentResponse"
},
{
"type": "object",
"required": [
"intent_type",
"request_details"
],
"properties": {
"action_result": {
"title": "BaseActionResult",
"description": "Result of transfer execution (only present if
intent status is 'executed' or 'failed')",
"allOf": [
{
"$ref": "#/components/schemas/BaseActionResult"
},
{
"type": "object",
"required": [
"response_body"
],
"properties": {
"response_body": {
"$ref": "#/components/schemas/TransferActionResponse"
}
}
}
],
"x-stainless-model": "intents.base_action_result"
},
"current_resource_data": {
"allOf": [
{
"$ref": "#/components/schemas/Wallet"
},
{
"description": "Current state of the wallet before any changes. If undefined, the resource was deleted and no longer exists"
}
]
},
"intent_type": {
"type": "string",
"enum": [
"TRANSFER"
]
},
"request_details": {
"description": "The original transfer request that would be
sent to the wallet transfer endpoint",
"type": "object",
"required": [
"body",
"method",
"url"
],
"properties": {
"body": {
"$ref": "#/components/schemas/TransferRequestBody"
},
"method": {
"type": "string",
"enum": [
"POST"
]
},
"url": {
"type": "string"
}
}
}
}
}
],
"x-stainless-model": "intents.transfer_intent_response"
}Fields
action_result: Option<BaseActionResult>Detailed authorization information including key quorum members, thresholds, and signature status
created_at: f64created_by_display_name: StringDisplay name of the user who created the intent
created_by_id: Option<String>ID of the user who created the intent. If undefined, the intent was created using the app secret
current_resource_data: Option<Wallet>custom_expiry: boolWhether this intent has a custom expiry time set by the client. If false, the intent expires after a default duration.
dismissal_reason: Option<String>Human-readable reason for dismissal, present when status is ‘dismissed’
dismissed_at: Option<f64>expires_at: f64intent_id: StringUnique ID for the intent
intent_type: TransferIntentResponseIntentTyperejected_at: Option<f64>request_details: TransferIntentResponseRequestDetailsresource_id: StringID of the resource being modified (wallet_id, policy_id, etc)
status: IntentStatusTrait Implementations
Sourceimpl Clone for TransferIntentResponse
impl Clone for TransferIntentResponse
Sourcefn clone(&self) -> TransferIntentResponse
fn clone(&self) -> TransferIntentResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransferIntentResponse
impl Debug for TransferIntentResponse
Sourceimpl<'de> Deserialize<'de> for TransferIntentResponse
impl<'de> Deserialize<'de> for TransferIntentResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&TransferIntentResponse> for TransferIntentResponse
impl From<&TransferIntentResponse> for TransferIntentResponse
Sourcefn from(value: &TransferIntentResponse) -> Self
fn from(value: &TransferIntentResponse) -> Self
Converts to this type from the input type.
Sourceimpl From<TransferIntentResponse> for IntentResponse
impl From<TransferIntentResponse> for IntentResponse
Sourcefn from(value: TransferIntentResponse) -> Self
fn from(value: TransferIntentResponse) -> Self
Converts to this type from the input type.