pub struct TransferIntentResponseRequestDetails {
pub body: TransferRequestBody,
pub method: TransferIntentResponseRequestDetailsMethod,
pub url: String,
}Expand description
The original transfer request that would be sent to the wallet transfer endpoint
JSON schema
{
"description": "The original transfer request that would be sent to the
wallet transfer endpoint",
"type": "object",
"required": [
"body",
"method",
"url"
],
"properties": {
"body": {
"$ref": "#/components/schemas/TransferRequestBody"
},
"method": {
"type": "string",
"enum": [
"POST"
]
},
"url": {
"type": "string"
}
}
}Fields
body: TransferRequestBodymethod: TransferIntentResponseRequestDetailsMethodurl: StringTrait Implementations
Sourceimpl Clone for TransferIntentResponseRequestDetails
impl Clone for TransferIntentResponseRequestDetails
Sourcefn clone(&self) -> TransferIntentResponseRequestDetails
fn clone(&self) -> TransferIntentResponseRequestDetails
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for TransferIntentResponseRequestDetails
impl<'de> Deserialize<'de> for TransferIntentResponseRequestDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&TransferIntentResponseRequestDetails> for TransferIntentResponseRequestDetails
impl From<&TransferIntentResponseRequestDetails> for TransferIntentResponseRequestDetails
Sourcefn from(value: &TransferIntentResponseRequestDetails) -> Self
fn from(value: &TransferIntentResponseRequestDetails) -> Self
Converts to this type from the input type.