pub struct TypedDataDomainInputParams(pub Map<String, Value>);Expand description
The domain parameters for EIP-712 typed data signing.
JSON schema
{
"title": "TypedDataDomainInputParams",
"description": "The domain parameters for EIP-712 typed data signing.",
"type": "object",
"additionalProperties": {
"x-stainless-any": true
},
"x-stainless-model": "wallets.typed_data_domain_input_params"
}Tuple Fields
0: Map<String, Value>Methods from Deref<Target = Map<String, Value>>
Sourcepub fn get<Q>(&self, key: &Q) -> Option<&Value>
pub fn get<Q>(&self, key: &Q) -> Option<&Value>
Returns a reference to the value corresponding to the key.
The key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.
Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
pub fn contains_key<Q>(&self, key: &Q) -> bool
Returns true if the map contains a value for the specified key.
The key may be any borrowed form of the map’s key type, but the ordering on the borrowed form must match the ordering on the key type.