pub struct UpdateAccountFromWalletIdsInput {
pub display_name: Option<AccountDisplayName>,
pub wallet_ids: AccountWalletIds,
}Expand description
Input for updating a digital asset account by adding existing wallets
with a wallet_ids parameter.
JSON schema
{
"title": "UpdateAccountFromWalletIdsInput",
"description": "Input for updating a digital asset account by adding
existing wallets with a `wallet_ids` parameter.",
"type": "object",
"required": [
"wallet_ids"
],
"properties": {
"display_name": {
"$ref": "#/components/schemas/AccountDisplayName"
},
"wallet_ids": {
"$ref": "#/components/schemas/AccountWalletIds"
}
},
"x-stainless-model": "accounts.update_account_from_wallet_ids_input"
}Fields
display_name: Option<AccountDisplayName>wallet_ids: AccountWalletIdsTrait Implementations
Sourceimpl Clone for UpdateAccountFromWalletIdsInput
impl Clone for UpdateAccountFromWalletIdsInput
Sourcefn clone(&self) -> UpdateAccountFromWalletIdsInput
fn clone(&self) -> UpdateAccountFromWalletIdsInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for UpdateAccountFromWalletIdsInput
impl<'de> Deserialize<'de> for UpdateAccountFromWalletIdsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&UpdateAccountFromWalletIdsInput> for UpdateAccountFromWalletIdsInput
impl From<&UpdateAccountFromWalletIdsInput> for UpdateAccountFromWalletIdsInput
Sourcefn from(value: &UpdateAccountFromWalletIdsInput) -> Self
fn from(value: &UpdateAccountFromWalletIdsInput) -> Self
Converts to this type from the input type.
Sourceimpl From<UpdateAccountFromWalletIdsInput> for UpdateAccountInput
impl From<UpdateAccountFromWalletIdsInput> for UpdateAccountInput
Sourcefn from(value: UpdateAccountFromWalletIdsInput) -> Self
fn from(value: UpdateAccountFromWalletIdsInput) -> Self
Converts to this type from the input type.