pub struct UpdateAccountFromWalletsConfigurationInput {
pub display_name: Option<AccountDisplayName>,
pub wallets_configuration: Option<AccountWalletsConfiguration>,
}Expand description
Input for updating a digital asset account with a
wallets_configuration specification.
JSON schema
{
"title": "UpdateAccountFromWalletsConfigurationInput",
"description": "Input for updating a digital asset account with a
`wallets_configuration` specification.",
"type": "object",
"properties": {
"display_name": {
"$ref": "#/components/schemas/AccountDisplayName"
},
"wallets_configuration": {
"$ref": "#/components/schemas/AccountWalletsConfiguration"
}
},
"x-stainless-model":
"accounts.update_account_from_wallets_configuration_input"
}Fields
display_name: Option<AccountDisplayName>wallets_configuration: Option<AccountWalletsConfiguration>Trait Implementations
Sourceimpl Clone for UpdateAccountFromWalletsConfigurationInput
impl Clone for UpdateAccountFromWalletsConfigurationInput
Sourcefn clone(&self) -> UpdateAccountFromWalletsConfigurationInput
fn clone(&self) -> UpdateAccountFromWalletsConfigurationInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for UpdateAccountFromWalletsConfigurationInput
impl<'de> Deserialize<'de> for UpdateAccountFromWalletsConfigurationInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&UpdateAccountFromWalletsConfigurationInput> for UpdateAccountFromWalletsConfigurationInput
impl From<&UpdateAccountFromWalletsConfigurationInput> for UpdateAccountFromWalletsConfigurationInput
Sourcefn from(value: &UpdateAccountFromWalletsConfigurationInput) -> Self
fn from(value: &UpdateAccountFromWalletsConfigurationInput) -> Self
Converts to this type from the input type.
Sourceimpl From<UpdateAccountFromWalletsConfigurationInput> for UpdateAccountInput
impl From<UpdateAccountFromWalletsConfigurationInput> for UpdateAccountInput
Sourcefn from(value: UpdateAccountFromWalletsConfigurationInput) -> Self
fn from(value: UpdateAccountFromWalletsConfigurationInput) -> Self
Converts to this type from the input type.