pub struct UpdateOrganizationSecretSigningKeyInput {
pub secret_id: UpdateOrganizationSecretSigningKeyInputSecretId,
pub signing_public_key: Option<String>,
}Expand description
Request body for updating the signing public key on an organization secret.
JSON schema
{
"title": "UpdateOrganizationSecretSigningKeyInput",
"description": "Request body for updating the signing public key on an
organization secret.",
"allOf": [
{
"$ref": "#/components/schemas/OrganizationSecretIdInput"
},
{
"type": "object",
"properties": {
"signing_public_key": {
"description": "P-256 public key in PEM format, or null to
clear the configured signing key.",
"type": "string"
}
}
}
],
"x-stainless-model":
"organizations.update_organization_secret_signing_key_input"
}Fields
secret_id: UpdateOrganizationSecretSigningKeyInputSecretIdThe organization secret ID.
signing_public_key: Option<String>P-256 public key in PEM format, or null to clear the configured signing key.