pub struct UserSigningKeyBinding(pub IntentBinding);Expand description
A binding that scopes a user signing key to a specific bound value.
JSON schema
{
"title": "UserSigningKeyBinding",
"description": "A binding that scopes a user signing key to a specific
bound value.",
"oneOf": [
{
"$ref": "#/components/schemas/IntentBinding"
}
],
"x-stainless-model": "wallets.user_signing_key_binding"
}Tuple Fields
0: IntentBindingTrait Implementations
Sourceimpl Clone for UserSigningKeyBinding
impl Clone for UserSigningKeyBinding
Sourcefn clone(&self) -> UserSigningKeyBinding
fn clone(&self) -> UserSigningKeyBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserSigningKeyBinding
impl Debug for UserSigningKeyBinding
Sourceimpl Deref for UserSigningKeyBinding
impl Deref for UserSigningKeyBinding
Sourcetype Target = IntentBinding
type Target = IntentBinding
The resulting type after dereferencing.
Sourcefn deref(&self) -> &IntentBinding
fn deref(&self) -> &IntentBinding
Dereferences the value.
Sourceimpl<'de> Deserialize<'de> for UserSigningKeyBinding
impl<'de> Deserialize<'de> for UserSigningKeyBinding
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&UserSigningKeyBinding> for UserSigningKeyBinding
impl From<&UserSigningKeyBinding> for UserSigningKeyBinding
Sourcefn from(value: &UserSigningKeyBinding) -> Self
fn from(value: &UserSigningKeyBinding) -> Self
Converts to this type from the input type.
Sourceimpl From<IntentBinding> for UserSigningKeyBinding
impl From<IntentBinding> for UserSigningKeyBinding
Sourcefn from(value: IntentBinding) -> Self
fn from(value: IntentBinding) -> Self
Converts to this type from the input type.
Sourceimpl From<UserSigningKeyBinding> for IntentBinding
impl From<UserSigningKeyBinding> for IntentBinding
Sourcefn from(value: UserSigningKeyBinding) -> Self
fn from(value: UserSigningKeyBinding) -> Self
Converts to this type from the input type.