pub struct Wallet {Show 14 fields
pub additional_signers: WalletAdditionalSigner,
pub address: String,
pub authorization_threshold: Option<f64>,
pub chain_type: WalletChainType,
pub created_at: f64,
pub custody: Option<WalletCustodian>,
pub display_name: Option<String>,
pub exported_at: Option<f64>,
pub external_id: Option<String>,
pub id: String,
pub imported_at: Option<f64>,
pub owner_id: Option<String>,
pub policy_ids: Vec<String>,
pub public_key: Option<String>,
}Expand description
A wallet managed by Privy’s wallet infrastructure.
JSON schema
{
"title": "Wallet",
"description": "A wallet managed by Privy's wallet infrastructure.",
"examples": [
{
"additional_signers": [],
"address": "0xF1DBff66C993EE895C8cb176c30b07A559d76496",
"chain_type": "ethereum",
"created_at": 1741834854578,
"display_name": "Treasury",
"exported_at": null,
"external_id": "my-order-123",
"id": "id2tptkqrxd39qo9j423etij",
"imported_at": null,
"owner_id": "rkiz0ivz254drv1xw982v3jq",
"policy_ids": []
}
],
"type": "object",
"required": [
"additional_signers",
"address",
"chain_type",
"created_at",
"id",
"policy_ids"
],
"properties": {
"additional_signers": {
"$ref": "#/components/schemas/WalletAdditionalSigner"
},
"address": {
"description": "Address of the wallet.",
"type": "string"
},
"authorization_threshold": {
"description": "The number of keys that must sign for an action to
be valid.",
"type": "number"
},
"chain_type": {
"$ref": "#/components/schemas/WalletChainType"
},
"created_at": {
"description": "Unix timestamp of when the wallet was created in
milliseconds.",
"type": "number"
},
"custody": {
"$ref": "#/components/schemas/WalletCustodian"
},
"display_name": {
"description": "A human-readable label for the wallet.",
"type": "string"
},
"exported_at": {
"description": "Unix timestamp of when the wallet was exported in
milliseconds, if the wallet was exported.",
"type": "number"
},
"external_id": {
"description": "A customer-provided identifier for mapping to
external systems. Write-once, set only at creation.",
"type": "string"
},
"id": {
"description": "Unique ID of the wallet. This will be the primary
identifier when using the wallet in the future.",
"type": "string"
},
"imported_at": {
"description": "Unix timestamp of when the wallet was imported in
milliseconds, if the wallet was imported.",
"type": "number"
},
"owner_id": {
"description": "The key quorum ID of the owner of the wallet.",
"type": "string",
"format": "cuid2"
},
"policy_ids": {
"description": "List of policy IDs for policies that are enforced
on the wallet.",
"type": "array",
"items": {
"type": "string"
}
},
"public_key": {
"description": "The compressed, raw public key for the wallet along
the chain cryptographic curve.",
"type": "string"
}
},
"x-stainless-model": "wallets.wallet"
}Fields
additional_signers: WalletAdditionalSigneraddress: StringAddress of the wallet.
chain_type: WalletChainTypecreated_at: f64custody: Option<WalletCustodian>display_name: Option<String>A human-readable label for the wallet.
exported_at: Option<f64>external_id: Option<String>A customer-provided identifier for mapping to external systems. Write-once, set only at creation.
id: StringUnique ID of the wallet. This will be the primary identifier when using the wallet in the future.
imported_at: Option<f64>owner_id: Option<String>The key quorum ID of the owner of the wallet.
policy_ids: Vec<String>List of policy IDs for policies that are enforced on the wallet.
public_key: Option<String>The compressed, raw public key for the wallet along the chain cryptographic curve.