pub struct WalletActionEarnIncentiveClaimRejectedWebhookPayload {
pub action_type: WalletActionType,
pub chain: String,
pub failure_reason: FailureReason,
pub rewards: Vec<EarnIncetiveClaimRewardEntry>,
pub status: WalletActionEarnIncentiveClaimRejectedWebhookPayloadStatus,
pub steps: Vec<WalletActionStep>,
pub type_: WalletActionEarnIncentiveClaimRejectedWebhookPayloadType,
pub wallet_action_id: String,
pub wallet_id: String,
}Expand description
Payload for the wallet_action.earn_incentive_claim.rejected webhook event.
JSON schema
{
"title": "WalletActionEarnIncentiveClaimRejectedWebhookPayload",
"description": "Payload for the
wallet_action.earn_incentive_claim.rejected webhook event.",
"type": "object",
"required": [
"action_type",
"chain",
"failure_reason",
"status",
"steps",
"type",
"wallet_action_id",
"wallet_id"
],
"properties": {
"action_type": {
"$ref": "#/components/schemas/WalletActionType"
},
"chain": {
"description": "EVM chain name (e.g. \"base\", \"ethereum\").",
"type": "string"
},
"failure_reason": {
"$ref": "#/components/schemas/FailureReason"
},
"rewards": {
"description": "Claimed reward tokens. Populated after the
preparation step fetches from Merkl.",
"type": "array",
"items": {
"$ref": "#/components/schemas/EarnIncetiveClaimRewardEntry"
}
},
"status": {
"description": "The status of the wallet action.",
"type": "string",
"enum": [
"rejected"
]
},
"steps": {
"description": "The steps of the wallet action at the time of
rejection.",
"type": "array",
"items": {
"$ref": "#/components/schemas/WalletActionStep"
}
},
"type": {
"description": "The type of webhook event.",
"type": "string",
"enum": [
"wallet_action.earn_incentive_claim.rejected"
]
},
"wallet_action_id": {
"description": "The ID of the wallet action.",
"type": "string"
},
"wallet_id": {
"description": "The ID of the wallet involved in the action.",
"type": "string"
}
},
"x-stainless-model":
"webhooks.wallet_action_earn_incentive_claim_rejected_webhook_payload"
}Fields
action_type: WalletActionTypechain: StringEVM chain name (e.g. “base”, “ethereum”).
failure_reason: FailureReasonrewards: Vec<EarnIncetiveClaimRewardEntry>Claimed reward tokens. Populated after the preparation step fetches from Merkl.
status: WalletActionEarnIncentiveClaimRejectedWebhookPayloadStatusThe status of the wallet action.
steps: Vec<WalletActionStep>The steps of the wallet action at the time of rejection.
type_: WalletActionEarnIncentiveClaimRejectedWebhookPayloadTypeThe type of webhook event.
wallet_action_id: StringThe ID of the wallet action.
wallet_id: StringThe ID of the wallet involved in the action.