pub struct WalletActionEarnWithdrawRejectedWebhookPayload {Show 15 fields
pub action_type: WalletActionType,
pub amount: Option<String>,
pub asset: Option<String>,
pub asset_address: String,
pub caip2: String,
pub decimals: Option<i64>,
pub failure_reason: FailureReason,
pub raw_amount: String,
pub status: WalletActionEarnWithdrawRejectedWebhookPayloadStatus,
pub steps: Vec<WalletActionStep>,
pub type_: WalletActionEarnWithdrawRejectedWebhookPayloadType,
pub vault_address: String,
pub vault_id: String,
pub wallet_action_id: String,
pub wallet_id: String,
}Expand description
Payload for the wallet_action.earn_withdraw.rejected webhook event.
JSON schema
{
"title": "WalletActionEarnWithdrawRejectedWebhookPayload",
"description": "Payload for the wallet_action.earn_withdraw.rejected
webhook event.",
"type": "object",
"required": [
"action_type",
"asset_address",
"caip2",
"failure_reason",
"raw_amount",
"status",
"steps",
"type",
"vault_address",
"vault_id",
"wallet_action_id",
"wallet_id"
],
"properties": {
"action_type": {
"$ref": "#/components/schemas/WalletActionType"
},
"amount": {
"description": "Human-readable decimal amount of asset withdrawn
(e.g. \"1.5\"). Only present when the token is known in the asset
registry.",
"type": "string"
},
"asset": {
"description": "Asset identifier (e.g. \"usdc\", \"eth\"). Only
present when the token is known in the asset registry.",
"type": "string"
},
"asset_address": {
"description": "Underlying asset token address.",
"type": "string"
},
"caip2": {
"description": "CAIP-2 chain identifier.",
"type": "string"
},
"decimals": {
"description": "Number of decimals for the underlying asset (e.g. 6
for USDC, 18 for ETH). Only present when the token is known in the asset
registry.",
"type": "integer"
},
"failure_reason": {
"$ref": "#/components/schemas/FailureReason"
},
"raw_amount": {
"description": "Base-unit amount of asset withdrawn (e.g.
\"1500000\").",
"type": "string"
},
"status": {
"description": "The status of the wallet action.",
"type": "string",
"enum": [
"rejected"
]
},
"steps": {
"description": "The steps of the wallet action at the time of
rejection.",
"type": "array",
"items": {
"$ref": "#/components/schemas/WalletActionStep"
}
},
"type": {
"description": "The type of webhook event.",
"type": "string",
"enum": [
"wallet_action.earn_withdraw.rejected"
]
},
"vault_address": {
"description": "ERC-4626 vault contract address.",
"type": "string"
},
"vault_id": {
"description": "The vault ID.",
"type": "string"
},
"wallet_action_id": {
"description": "The ID of the wallet action.",
"type": "string"
},
"wallet_id": {
"description": "The ID of the wallet involved in the action.",
"type": "string"
}
},
"x-stainless-model":
"webhooks.wallet_action_earn_withdraw_rejected_webhook_payload"
}Fields
action_type: WalletActionTypeamount: Option<String>Human-readable decimal amount of asset withdrawn (e.g. “1.5”). Only present when the token is known in the asset registry.
asset: Option<String>Asset identifier (e.g. “usdc”, “eth”). Only present when the token is known in the asset registry.
asset_address: StringUnderlying asset token address.
caip2: StringCAIP-2 chain identifier.
decimals: Option<i64>Number of decimals for the underlying asset (e.g. 6 for USDC, 18 for ETH). Only present when the token is known in the asset registry.
failure_reason: FailureReasonraw_amount: StringBase-unit amount of asset withdrawn (e.g. “1500000”).
status: WalletActionEarnWithdrawRejectedWebhookPayloadStatusThe status of the wallet action.
steps: Vec<WalletActionStep>The steps of the wallet action at the time of rejection.
type_: WalletActionEarnWithdrawRejectedWebhookPayloadTypeThe type of webhook event.
vault_address: StringERC-4626 vault contract address.
vault_id: StringThe vault ID.
wallet_action_id: StringThe ID of the wallet action.
wallet_id: StringThe ID of the wallet involved in the action.