pub struct WalletActionTransferSucceededWebhookPayload {
pub action_type: WalletActionType,
pub destination_address: String,
pub source_amount: Option<String>,
pub source_asset: Option<String>,
pub source_asset_address: Option<String>,
pub source_asset_decimals: Option<i64>,
pub source_chain: String,
pub status: WalletActionTransferSucceededWebhookPayloadStatus,
pub steps: Vec<WalletActionStep>,
pub type_: WalletActionTransferSucceededWebhookPayloadType,
pub wallet_action_id: String,
pub wallet_id: String,
}Expand description
Payload for the wallet_action.transfer.succeeded webhook event.
JSON schema
{
"title": "WalletActionTransferSucceededWebhookPayload",
"description": "Payload for the wallet_action.transfer.succeeded
webhook event.",
"type": "object",
"required": [
"action_type",
"destination_address",
"source_chain",
"status",
"steps",
"type",
"wallet_action_id",
"wallet_id"
],
"properties": {
"action_type": {
"$ref": "#/components/schemas/WalletActionType"
},
"destination_address": {
"description": "Recipient address.",
"type": "string"
},
"source_amount": {
"description": "Decimal amount sent on the source chain (e.g.
\"1.5\"). Omitted for exact_output cross-chain transfers until the
source amount is determined.",
"type": "string"
},
"source_asset": {
"description": "Asset identifier (e.g. \"usdc\", \"eth\"). Present
when the transfer was initiated with a named asset; omitted for
custom-token transfers.",
"type": "string"
},
"source_asset_address": {
"description": "Token contract address (EVM) or mint address
(Solana). Present when the transfer was initiated with
`asset_address`.",
"type": "string"
},
"source_asset_decimals": {
"description": "Number of decimals for the transferred token.
Present when the transfer was initiated with `asset_address` and the
decimals were resolved on-chain.",
"type": "integer"
},
"source_chain": {
"description": "Chain name (e.g. \"base\", \"ethereum\").",
"type": "string"
},
"status": {
"description": "The status of the wallet action.",
"type": "string",
"enum": [
"succeeded"
]
},
"steps": {
"description": "The steps of the wallet action, including
transaction hashes.",
"type": "array",
"items": {
"$ref": "#/components/schemas/WalletActionStep"
}
},
"type": {
"description": "The type of webhook event.",
"type": "string",
"enum": [
"wallet_action.transfer.succeeded"
]
},
"wallet_action_id": {
"description": "The ID of the wallet action.",
"type": "string"
},
"wallet_id": {
"description": "The ID of the wallet involved in the action.",
"type": "string"
}
},
"x-stainless-model":
"webhooks.wallet_action_transfer_succeeded_webhook_payload"
}Fields
action_type: WalletActionTypedestination_address: StringRecipient address.
source_amount: Option<String>Decimal amount sent on the source chain (e.g. “1.5”). Omitted for exact_output cross-chain transfers until the source amount is determined.
source_asset: Option<String>Asset identifier (e.g. “usdc”, “eth”). Present when the transfer was initiated with a named asset; omitted for custom-token transfers.
source_asset_address: Option<String>Token contract address (EVM) or mint address (Solana). Present when
the transfer was initiated with asset_address.
source_asset_decimals: Option<i64>Number of decimals for the transferred token. Present when the
transfer was initiated with asset_address and the decimals were
resolved on-chain.
source_chain: StringChain name (e.g. “base”, “ethereum”).
status: WalletActionTransferSucceededWebhookPayloadStatusThe status of the wallet action.
steps: Vec<WalletActionStep>The steps of the wallet action, including transaction hashes.
type_: WalletActionTransferSucceededWebhookPayloadTypeThe type of webhook event.
wallet_action_id: StringThe ID of the wallet action.
wallet_id: StringThe ID of the wallet involved in the action.