pub struct WalletAuthenticateRequestBody {
pub encryption_type: WalletAuthenticateRequestBodyEncryptionType,
pub recipient_public_key: String,
pub user_jwt: String,
}Expand description
Request body for wallet authentication with HPKE-encrypted response.
JSON schema
{
"title": "WalletAuthenticateRequestBody",
"description": "Request body for wallet authentication with
HPKE-encrypted response.",
"type": "object",
"required": [
"encryption_type",
"recipient_public_key",
"user_jwt"
],
"properties": {
"encryption_type": {
"description": "The encryption type for the authentication
response. Currently only supports HPKE.",
"type": "string",
"enum": [
"HPKE"
]
},
"recipient_public_key": {
"description": "The public key of your ECDH keypair, in
base64-encoded, SPKI-format, whose private key will be able to decrypt
the session key.",
"type": "string"
},
"user_jwt": {
"description": "The user's JWT, to be used to authenticate the
user.",
"type": "string"
}
},
"x-stainless-model": "wallets.wallet_authenticate_request_body"
}Fields
encryption_type: WalletAuthenticateRequestBodyEncryptionTypeThe encryption type for the authentication response. Currently only supports HPKE.
recipient_public_key: StringThe public key of your ECDH keypair, in base64-encoded, SPKI-format, whose private key will be able to decrypt the session key.
user_jwt: StringThe user’s JWT, to be used to authenticate the user.