pub struct WalletBatchItemInput {
pub additional_signers: Option<AdditionalSignerInput>,
pub chain_type: WalletChainType,
pub display_name: Option<WalletBatchItemInputDisplayName>,
pub external_id: Option<WalletBatchItemInputExternalId>,
pub owner: Option<OwnerInput>,
pub owner_id: Option<OwnerIdInput>,
pub policy_ids: Vec<WalletBatchItemInputPolicyIdsItem>,
}Expand description
Input for a single wallet in a batch creation request.
JSON schema
{
"title": "WalletBatchItemInput",
"description": "Input for a single wallet in a batch creation
request.",
"examples": [
{
"chain_type": "ethereum"
}
],
"type": "object",
"required": [
"chain_type"
],
"properties": {
"additional_signers": {
"$ref": "#/components/schemas/AdditionalSignerInput"
},
"chain_type": {
"$ref": "#/components/schemas/WalletChainType"
},
"display_name": {
"description": "A human-readable label for the wallet.",
"type": "string",
"maxLength": 100
},
"external_id": {
"description": "A customer-provided identifier for mapping to
external systems. URL-safe characters only ([a-zA-Z0-9_-]), max 64
chars. Write-once: cannot be changed after creation.",
"type": "string",
"maxLength": 64,
"pattern": "^[a-zA-Z0-9_-]+$"
},
"owner": {
"$ref": "#/components/schemas/OwnerInput"
},
"owner_id": {
"$ref": "#/components/schemas/OwnerIdInput"
},
"policy_ids": {
"description": "List of policy IDs for policies that should be
enforced on the wallet. Currently, only one policy is supported per
wallet.",
"type": "array",
"items": {
"type": "string",
"maxLength": 24,
"minLength": 24
},
"maxItems": 1
}
},
"x-stainless-model": "wallets.wallet_batch_item_input"
}Fields
additional_signers: Option<AdditionalSignerInput>chain_type: WalletChainTypedisplay_name: Option<WalletBatchItemInputDisplayName>A human-readable label for the wallet.
external_id: Option<WalletBatchItemInputExternalId>A customer-provided identifier for mapping to external systems. URL-safe characters only ([a-zA-Z0-9_-]), max 64 chars. Write-once: cannot be changed after creation.
owner: Option<OwnerInput>owner_id: Option<OwnerIdInput>policy_ids: Vec<WalletBatchItemInputPolicyIdsItem>List of policy IDs for policies that should be enforced on the wallet. Currently, only one policy is supported per wallet.