pub struct WalletCreationInput {
pub additional_signers: Vec<WalletCreationAdditionalSignerItem>,
pub chain_type: WalletChainType,
pub create_smart_wallet: Option<bool>,
pub policy_ids: Vec<WalletCreationInputPolicyIdsItem>,
}Expand description
The fields on wallet creation that can be specified when creating a user-controlled embedded server wallet.
JSON schema
{
"title": "WalletCreationInput",
"description": "The fields on wallet creation that can be specified
when creating a user-controlled embedded server wallet.",
"type": "object",
"required": [
"chain_type"
],
"properties": {
"additional_signers": {
"description": "Additional signers for the wallet.",
"type": "array",
"items": {
"$ref": "#/components/schemas/WalletCreationAdditionalSignerItem"
}
},
"chain_type": {
"$ref": "#/components/schemas/WalletChainType"
},
"create_smart_wallet": {
"description": "Create a smart wallet with this wallet as the signer. Only supported for wallets with `chain_type: \"ethereum\"`.",
"type": "boolean"
},
"policy_ids": {
"description": "Policy IDs to enforce on the wallet. Currently,
only one policy is supported per wallet.",
"type": "array",
"items": {
"type": "string",
"maxLength": 24,
"minLength": 24
},
"maxItems": 1
}
},
"x-stainless-model": "embedded_wallets.wallet_creation_input"
}Fields
additional_signers: Vec<WalletCreationAdditionalSignerItem>Additional signers for the wallet.
chain_type: WalletChainTypecreate_smart_wallet: Option<bool>Create a smart wallet with this wallet as the signer. Only supported
for wallets with chain_type: "ethereum".
policy_ids: Vec<WalletCreationInputPolicyIdsItem>Policy IDs to enforce on the wallet. Currently, only one policy is supported per wallet.