pub struct WalletIntentResponse {Show 16 fields
pub action_result: Option<BaseActionResult>,
pub authorization_details: Vec<IntentAuthorization>,
pub created_at: f64,
pub created_by_display_name: String,
pub created_by_id: Option<String>,
pub current_resource_data: Option<Wallet>,
pub custom_expiry: bool,
pub dismissal_reason: Option<String>,
pub dismissed_at: Option<f64>,
pub expires_at: f64,
pub intent_id: String,
pub intent_type: WalletIntentResponseIntentType,
pub rejected_at: Option<f64>,
pub request_details: WalletIntentResponseRequestDetails,
pub resource_id: String,
pub status: IntentStatus,
}Expand description
Response for a wallet intent
JSON schema
{
"title": "WalletIntentResponse",
"description": "Response for a wallet intent",
"allOf": [
{
"$ref": "#/components/schemas/BaseIntentResponse"
},
{
"type": "object",
"required": [
"intent_type",
"request_details"
],
"properties": {
"action_result": {
"title": "BaseActionResult",
"description": "Result of wallet update execution (only present
if status is 'executed' or 'failed')",
"allOf": [
{
"$ref": "#/components/schemas/BaseActionResult"
},
{
"type": "object",
"required": [
"prior_state",
"response_body"
],
"properties": {
"prior_state": {
"allOf": [
{
"$ref": "#/components/schemas/Wallet"
},
{
"description": "State of the wallet immediately
before execution"
}
]
},
"response_body": {
"$ref": "#/components/schemas/Wallet"
}
}
}
],
"x-stainless-model": "intents.base_action_result"
},
"current_resource_data": {
"allOf": [
{
"$ref": "#/components/schemas/Wallet"
},
{
"description": "Current state of the wallet before any changes. If undefined, the resource was deleted and no longer exists"
}
]
},
"intent_type": {
"type": "string",
"enum": [
"WALLET"
]
},
"request_details": {
"description": "The original wallet update request that would
be sent to the wallet endpoint",
"type": "object",
"required": [
"body",
"method",
"url"
],
"properties": {
"body": {
"type": "object",
"properties": {
"additional_signers": {
"$ref": "#/components/schemas/AdditionalSignerInput"
},
"authorization_key_ids": {
"type": "array",
"items": {
"type": "string"
}
},
"authorization_threshold": {
"type": "number"
},
"display_name": {
"type": "string",
"maxLength": 100
},
"owner": {
"$ref": "#/components/schemas/OwnerInput"
},
"owner_id": {
"$ref": "#/components/schemas/OwnerIdInput"
},
"policy_ids": {
"$ref": "#/components/schemas/PolicyInput"
}
}
},
"method": {
"type": "string",
"enum": [
"PATCH"
]
},
"url": {
"type": "string"
}
}
}
}
}
],
"x-stainless-model": "intents.wallet_intent_response"
}Fields
action_result: Option<BaseActionResult>Detailed authorization information including key quorum members, thresholds, and signature status
created_at: f64created_by_display_name: StringDisplay name of the user who created the intent
created_by_id: Option<String>ID of the user who created the intent. If undefined, the intent was created using the app secret
current_resource_data: Option<Wallet>custom_expiry: boolWhether this intent has a custom expiry time set by the client. If false, the intent expires after a default duration.
dismissal_reason: Option<String>Human-readable reason for dismissal, present when status is ‘dismissed’
dismissed_at: Option<f64>expires_at: f64intent_id: StringUnique ID for the intent
intent_type: WalletIntentResponseIntentTyperejected_at: Option<f64>request_details: WalletIntentResponseRequestDetailsresource_id: StringID of the resource being modified (wallet_id, policy_id, etc)
status: IntentStatusTrait Implementations
Sourceimpl Clone for WalletIntentResponse
impl Clone for WalletIntentResponse
Sourcefn clone(&self) -> WalletIntentResponse
fn clone(&self) -> WalletIntentResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WalletIntentResponse
impl Debug for WalletIntentResponse
Sourceimpl<'de> Deserialize<'de> for WalletIntentResponse
impl<'de> Deserialize<'de> for WalletIntentResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&WalletIntentResponse> for WalletIntentResponse
impl From<&WalletIntentResponse> for WalletIntentResponse
Sourcefn from(value: &WalletIntentResponse) -> Self
fn from(value: &WalletIntentResponse) -> Self
Converts to this type from the input type.
Sourceimpl From<WalletIntentResponse> for IntentResponse
impl From<WalletIntentResponse> for IntentResponse
Sourcefn from(value: WalletIntentResponse) -> Self
fn from(value: WalletIntentResponse) -> Self
Converts to this type from the input type.