pub struct WalletIntentResponseRequestDetails {
pub body: WalletIntentResponseRequestDetailsBody,
pub method: WalletIntentResponseRequestDetailsMethod,
pub url: String,
}Expand description
The original wallet update request that would be sent to the wallet endpoint
JSON schema
{
"description": "The original wallet update request that would be sent
to the wallet endpoint",
"type": "object",
"required": [
"body",
"method",
"url"
],
"properties": {
"body": {
"type": "object",
"properties": {
"additional_signers": {
"$ref": "#/components/schemas/WalletAdditionalSigner"
},
"owner": {
"$ref": "#/components/schemas/OwnerInput"
},
"owner_id": {
"allOf": [
{
"$ref": "#/components/schemas/OwnerIdInput"
},
{}
]
},
"policy_ids": {
"description": "New policy IDs to enforce on the wallet.
Currently, only one policy is supported per wallet.",
"type": "array",
"items": {
"type": "string",
"maxLength": 24,
"minLength": 24
},
"maxItems": 1
}
}
},
"method": {
"type": "string",
"enum": [
"PATCH"
]
},
"url": {
"type": "string"
}
}
}Fields
body: WalletIntentResponseRequestDetailsBodymethod: WalletIntentResponseRequestDetailsMethodurl: StringTrait Implementations
Sourceimpl Clone for WalletIntentResponseRequestDetails
impl Clone for WalletIntentResponseRequestDetails
Sourcefn clone(&self) -> WalletIntentResponseRequestDetails
fn clone(&self) -> WalletIntentResponseRequestDetails
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for WalletIntentResponseRequestDetails
impl<'de> Deserialize<'de> for WalletIntentResponseRequestDetails
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&WalletIntentResponseRequestDetails> for WalletIntentResponseRequestDetails
impl From<&WalletIntentResponseRequestDetails> for WalletIntentResponseRequestDetails
Sourcefn from(value: &WalletIntentResponseRequestDetails) -> Self
fn from(value: &WalletIntentResponseRequestDetails) -> Self
Converts to this type from the input type.