pub struct EthereumVaultResponse {
pub asset_address: String,
pub caip2: String,
pub created_at: f64,
pub id: String,
pub provider: EthereumYieldProvider,
pub underlying_vault_address: String,
pub vault_address: String,
}Expand description
A vault configuration for yield features.
JSON schema
{
"title": "EthereumVaultResponse",
"description": "A vault configuration for yield features.",
"examples": [
{
"asset_address": "0xabcdef1234567890abcdef1234567890abcdef12",
"caip2": "eip155:8453",
"created_at": 1631573050000,
"id": "cm7oxq1el000e11o8iwp7d0d0",
"provider": "morpho",
"underlying_vault_address":
"0x1234567890abcdef1234567890abcdef12345678",
"vault_address": "0x1234567890abcdef1234567890abcdef12345678"
}
],
"type": "object",
"required": [
"asset_address",
"caip2",
"created_at",
"id",
"provider",
"underlying_vault_address",
"vault_address"
],
"properties": {
"asset_address": {
"description": "The address of the underlying asset token (e.g.,
USDC).",
"type": "string"
},
"caip2": {
"description": "The CAIP-2 chain identifier.",
"type": "string"
},
"created_at": {
"description": "Unix timestamp of when the vault was created, in
milliseconds.",
"type": "number"
},
"id": {
"description": "Unique identifier for the vault.",
"type": "string"
},
"provider": {
"$ref": "#/components/schemas/EthereumYieldProvider"
},
"underlying_vault_address": {
"description": "The address of the underlying vault that the fee vault wraps. If this is not a fee vault, this equals vault_address.",
"type": "string"
},
"vault_address": {
"description": "The on-chain address of the ERC-4626 vault
contract.",
"type": "string"
}
},
"x-stainless-model": "yield.ethereum_vault_response"
}Fields
asset_address: StringThe address of the underlying asset token (e.g., USDC).
caip2: StringThe CAIP-2 chain identifier.
created_at: f64id: StringUnique identifier for the vault.
provider: EthereumYieldProviderunderlying_vault_address: StringThe address of the underlying vault that the fee vault wraps. If this is not a fee vault, this equals vault_address.
vault_address: StringThe on-chain address of the ERC-4626 vault contract.