pub struct PolicyIntentResponse {Show 16 fields
pub action_result: Option<BaseActionResult>,
pub authorization_details: Vec<IntentAuthorization>,
pub created_at: f64,
pub created_by_display_name: String,
pub created_by_id: Option<String>,
pub current_resource_data: Option<Policy>,
pub custom_expiry: bool,
pub dismissal_reason: Option<String>,
pub dismissed_at: Option<f64>,
pub expires_at: f64,
pub intent_id: String,
pub intent_type: PolicyIntentResponseIntentType,
pub rejected_at: Option<f64>,
pub request_details: PolicyIntentResponseRequestDetails,
pub resource_id: String,
pub status: IntentStatus,
}Expand description
Response for a policy intent
JSON schema
{
"title": "PolicyIntentResponse",
"description": "Response for a policy intent",
"allOf": [
{
"$ref": "#/components/schemas/BaseIntentResponse"
},
{
"type": "object",
"required": [
"intent_type",
"request_details"
],
"properties": {
"action_result": {
"title": "BaseActionResult",
"description": "Result of policy update execution (only present
if status is 'executed' or 'failed')",
"allOf": [
{
"$ref": "#/components/schemas/BaseActionResult"
},
{
"type": "object",
"required": [
"prior_state",
"response_body"
],
"properties": {
"prior_state": {
"allOf": [
{
"$ref": "#/components/schemas/Policy"
},
{
"description": "State of the policy immediately
before execution"
}
]
},
"response_body": {
"$ref": "#/components/schemas/Policy"
}
}
}
],
"x-stainless-model": "intents.base_action_result"
},
"current_resource_data": {
"allOf": [
{
"$ref": "#/components/schemas/Policy"
},
{
"description": "Current state of the policy before any changes. If undefined, the resource was deleted and no longer exists"
}
]
},
"intent_type": {
"type": "string",
"enum": [
"POLICY"
]
},
"request_details": {
"description": "The original policy update request that would
be sent to the policy endpoint",
"type": "object",
"required": [
"body",
"method",
"url"
],
"properties": {
"body": {
"type": "object",
"properties": {
"name": {
"description": "Name to assign to policy.",
"type": "string",
"maxLength": 50,
"minLength": 1
},
"owner": {
"$ref": "#/components/schemas/OwnerInput"
},
"owner_id": {
"$ref": "#/components/schemas/OwnerIdInput"
},
"rules": {
"type": "array",
"items": {
"$ref": "#/components/schemas/PolicyRuleRequestBody"
}
}
}
},
"method": {
"type": "string",
"enum": [
"PATCH"
]
},
"url": {
"type": "string"
}
}
}
}
}
],
"x-stainless-model": "intents.policy_intent_response"
}Fields
action_result: Option<BaseActionResult>Detailed authorization information including key quorum members, thresholds, and signature status
created_at: f64created_by_display_name: StringDisplay name of the user who created the intent
created_by_id: Option<String>ID of the user who created the intent. If undefined, the intent was created using the app secret
current_resource_data: Option<Policy>custom_expiry: boolWhether this intent has a custom expiry time set by the client. If false, the intent expires after a default duration.
dismissal_reason: Option<String>Human-readable reason for dismissal, present when status is ‘dismissed’
dismissed_at: Option<f64>expires_at: f64intent_id: StringUnique ID for the intent
intent_type: PolicyIntentResponseIntentTyperejected_at: Option<f64>request_details: PolicyIntentResponseRequestDetailsresource_id: StringID of the resource being modified (wallet_id, policy_id, etc)
status: IntentStatusTrait Implementations
Sourceimpl Clone for PolicyIntentResponse
impl Clone for PolicyIntentResponse
Sourcefn clone(&self) -> PolicyIntentResponse
fn clone(&self) -> PolicyIntentResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PolicyIntentResponse
impl Debug for PolicyIntentResponse
Sourceimpl<'de> Deserialize<'de> for PolicyIntentResponse
impl<'de> Deserialize<'de> for PolicyIntentResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&PolicyIntentResponse> for PolicyIntentResponse
impl From<&PolicyIntentResponse> for PolicyIntentResponse
Sourcefn from(value: &PolicyIntentResponse) -> Self
fn from(value: &PolicyIntentResponse) -> Self
Converts to this type from the input type.
Sourceimpl From<PolicyIntentResponse> for IntentResponse
impl From<PolicyIntentResponse> for IntentResponse
Sourcefn from(value: PolicyIntentResponse) -> Self
fn from(value: PolicyIntentResponse) -> Self
Converts to this type from the input type.